// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: apparmor.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type AaPolicy struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Name *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
	Blob []byte  `protobuf:"bytes,2,req,name=blob" json:"blob,omitempty"`
}

func (x *AaPolicy) Reset() {
	*x = AaPolicy{}
	if protoimpl.UnsafeEnabled {
		mi := &file_apparmor_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *AaPolicy) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AaPolicy) ProtoMessage() {}

func (x *AaPolicy) ProtoReflect() protoreflect.Message {
	mi := &file_apparmor_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AaPolicy.ProtoReflect.Descriptor instead.
func (*AaPolicy) Descriptor() ([]byte, []int) {
	return file_apparmor_proto_rawDescGZIP(), []int{0}
}

func (x *AaPolicy) GetName() string {
	if x != nil && x.Name != nil {
		return *x.Name
	}
	return ""
}

func (x *AaPolicy) GetBlob() []byte {
	if x != nil {
		return x.Blob
	}
	return nil
}

type AaNamespace struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Name       *string        `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
	Policies   []*AaPolicy    `protobuf:"bytes,2,rep,name=policies" json:"policies,omitempty"`
	Namespaces []*AaNamespace `protobuf:"bytes,3,rep,name=namespaces" json:"namespaces,omitempty"`
}

func (x *AaNamespace) Reset() {
	*x = AaNamespace{}
	if protoimpl.UnsafeEnabled {
		mi := &file_apparmor_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *AaNamespace) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AaNamespace) ProtoMessage() {}

func (x *AaNamespace) ProtoReflect() protoreflect.Message {
	mi := &file_apparmor_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AaNamespace.ProtoReflect.Descriptor instead.
func (*AaNamespace) Descriptor() ([]byte, []int) {
	return file_apparmor_proto_rawDescGZIP(), []int{1}
}

func (x *AaNamespace) GetName() string {
	if x != nil && x.Name != nil {
		return *x.Name
	}
	return ""
}

func (x *AaNamespace) GetPolicies() []*AaPolicy {
	if x != nil {
		return x.Policies
	}
	return nil
}

func (x *AaNamespace) GetNamespaces() []*AaNamespace {
	if x != nil {
		return x.Namespaces
	}
	return nil
}

type ApparmorEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Namespaces []*AaNamespace `protobuf:"bytes,1,rep,name=namespaces" json:"namespaces,omitempty"`
}

func (x *ApparmorEntry) Reset() {
	*x = ApparmorEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_apparmor_proto_msgTypes[2]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *ApparmorEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApparmorEntry) ProtoMessage() {}

func (x *ApparmorEntry) ProtoReflect() protoreflect.Message {
	mi := &file_apparmor_proto_msgTypes[2]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApparmorEntry.ProtoReflect.Descriptor instead.
func (*ApparmorEntry) Descriptor() ([]byte, []int) {
	return file_apparmor_proto_rawDescGZIP(), []int{2}
}

func (x *ApparmorEntry) GetNamespaces() []*AaNamespace {
	if x != nil {
		return x.Namespaces
	}
	return nil
}

var File_apparmor_proto protoreflect.FileDescriptor

var file_apparmor_proto_rawDesc = []byte{
	0x0a, 0x0e, 0x61, 0x70, 0x70, 0x61, 0x72, 0x6d, 0x6f, 0x72, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x22, 0x33, 0x0a, 0x09, 0x61, 0x61, 0x5f, 0x70, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x12, 0x12, 0x0a,
	0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d,
	0x65, 0x12, 0x12, 0x0a, 0x04, 0x62, 0x6c, 0x6f, 0x62, 0x18, 0x02, 0x20, 0x02, 0x28, 0x0c, 0x52,
	0x04, 0x62, 0x6c, 0x6f, 0x62, 0x22, 0x79, 0x0a, 0x0c, 0x61, 0x61, 0x5f, 0x6e, 0x61, 0x6d, 0x65,
	0x73, 0x70, 0x61, 0x63, 0x65, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20,
	0x02, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x26, 0x0a, 0x08, 0x70, 0x6f, 0x6c,
	0x69, 0x63, 0x69, 0x65, 0x73, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x0a, 0x2e, 0x61, 0x61,
	0x5f, 0x70, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x52, 0x08, 0x70, 0x6f, 0x6c, 0x69, 0x63, 0x69, 0x65,
	0x73, 0x12, 0x2d, 0x0a, 0x0a, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x70, 0x61, 0x63, 0x65, 0x73, 0x18,
	0x03, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x0d, 0x2e, 0x61, 0x61, 0x5f, 0x6e, 0x61, 0x6d, 0x65, 0x73,
	0x70, 0x61, 0x63, 0x65, 0x52, 0x0a, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x70, 0x61, 0x63, 0x65, 0x73,
	0x22, 0x3f, 0x0a, 0x0e, 0x61, 0x70, 0x70, 0x61, 0x72, 0x6d, 0x6f, 0x72, 0x5f, 0x65, 0x6e, 0x74,
	0x72, 0x79, 0x12, 0x2d, 0x0a, 0x0a, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x70, 0x61, 0x63, 0x65, 0x73,
	0x18, 0x01, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x0d, 0x2e, 0x61, 0x61, 0x5f, 0x6e, 0x61, 0x6d, 0x65,
	0x73, 0x70, 0x61, 0x63, 0x65, 0x52, 0x0a, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x70, 0x61, 0x63, 0x65,
	0x73,
}

var (
	file_apparmor_proto_rawDescOnce sync.Once
	file_apparmor_proto_rawDescData = file_apparmor_proto_rawDesc
)

func file_apparmor_proto_rawDescGZIP() []byte {
	file_apparmor_proto_rawDescOnce.Do(func() {
		file_apparmor_proto_rawDescData = protoimpl.X.CompressGZIP(file_apparmor_proto_rawDescData)
	})
	return file_apparmor_proto_rawDescData
}

var file_apparmor_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_apparmor_proto_goTypes = []interface{}{
	(*AaPolicy)(nil),      // 0: aa_policy
	(*AaNamespace)(nil),   // 1: aa_namespace
	(*ApparmorEntry)(nil), // 2: apparmor_entry
}
var file_apparmor_proto_depIdxs = []int32{
	0, // 0: aa_namespace.policies:type_name -> aa_policy
	1, // 1: aa_namespace.namespaces:type_name -> aa_namespace
	1, // 2: apparmor_entry.namespaces:type_name -> aa_namespace
	3, // [3:3] is the sub-list for method output_type
	3, // [3:3] is the sub-list for method input_type
	3, // [3:3] is the sub-list for extension type_name
	3, // [3:3] is the sub-list for extension extendee
	0, // [0:3] is the sub-list for field type_name
}

func init() { file_apparmor_proto_init() }
func file_apparmor_proto_init() {
	if File_apparmor_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_apparmor_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*AaPolicy); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_apparmor_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*AaNamespace); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_apparmor_proto_msgTypes[2].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*ApparmorEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_apparmor_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   3,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_apparmor_proto_goTypes,
		DependencyIndexes: file_apparmor_proto_depIdxs,
		MessageInfos:      file_apparmor_proto_msgTypes,
	}.Build()
	File_apparmor_proto = out.File
	file_apparmor_proto_rawDesc = nil
	file_apparmor_proto_goTypes = nil
	file_apparmor_proto_depIdxs = nil
}
