// SPDX-License-Identifier: MIT

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: tun.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type TunfileEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Id       *uint32 `protobuf:"varint,1,req,name=id" json:"id,omitempty"`
	Netdev   *string `protobuf:"bytes,2,opt,name=netdev" json:"netdev,omitempty"`
	Detached *bool   `protobuf:"varint,3,opt,name=detached" json:"detached,omitempty"`
	NsId     *uint32 `protobuf:"varint,4,opt,name=ns_id,json=nsId" json:"ns_id,omitempty"`
}

func (x *TunfileEntry) Reset() {
	*x = TunfileEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_tun_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TunfileEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TunfileEntry) ProtoMessage() {}

func (x *TunfileEntry) ProtoReflect() protoreflect.Message {
	mi := &file_tun_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TunfileEntry.ProtoReflect.Descriptor instead.
func (*TunfileEntry) Descriptor() ([]byte, []int) {
	return file_tun_proto_rawDescGZIP(), []int{0}
}

func (x *TunfileEntry) GetId() uint32 {
	if x != nil && x.Id != nil {
		return *x.Id
	}
	return 0
}

func (x *TunfileEntry) GetNetdev() string {
	if x != nil && x.Netdev != nil {
		return *x.Netdev
	}
	return ""
}

func (x *TunfileEntry) GetDetached() bool {
	if x != nil && x.Detached != nil {
		return *x.Detached
	}
	return false
}

func (x *TunfileEntry) GetNsId() uint32 {
	if x != nil && x.NsId != nil {
		return *x.NsId
	}
	return 0
}

type TunLinkEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Flags   *uint32 `protobuf:"varint,1,req,name=flags" json:"flags,omitempty"`
	Owner   *int32  `protobuf:"varint,2,req,name=owner" json:"owner,omitempty"`
	Group   *int32  `protobuf:"varint,3,req,name=group" json:"group,omitempty"`
	Vnethdr *uint32 `protobuf:"varint,4,req,name=vnethdr" json:"vnethdr,omitempty"`
	Sndbuf  *uint32 `protobuf:"varint,5,req,name=sndbuf" json:"sndbuf,omitempty"`
}

func (x *TunLinkEntry) Reset() {
	*x = TunLinkEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_tun_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TunLinkEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TunLinkEntry) ProtoMessage() {}

func (x *TunLinkEntry) ProtoReflect() protoreflect.Message {
	mi := &file_tun_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TunLinkEntry.ProtoReflect.Descriptor instead.
func (*TunLinkEntry) Descriptor() ([]byte, []int) {
	return file_tun_proto_rawDescGZIP(), []int{1}
}

func (x *TunLinkEntry) GetFlags() uint32 {
	if x != nil && x.Flags != nil {
		return *x.Flags
	}
	return 0
}

func (x *TunLinkEntry) GetOwner() int32 {
	if x != nil && x.Owner != nil {
		return *x.Owner
	}
	return 0
}

func (x *TunLinkEntry) GetGroup() int32 {
	if x != nil && x.Group != nil {
		return *x.Group
	}
	return 0
}

func (x *TunLinkEntry) GetVnethdr() uint32 {
	if x != nil && x.Vnethdr != nil {
		return *x.Vnethdr
	}
	return 0
}

func (x *TunLinkEntry) GetSndbuf() uint32 {
	if x != nil && x.Sndbuf != nil {
		return *x.Sndbuf
	}
	return 0
}

var File_tun_proto protoreflect.FileDescriptor

var file_tun_proto_rawDesc = []byte{
	0x0a, 0x09, 0x74, 0x75, 0x6e, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x0a, 0x6f, 0x70, 0x74,
	0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x68, 0x0a, 0x0d, 0x74, 0x75, 0x6e, 0x66, 0x69,
	0x6c, 0x65, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x0e, 0x0a, 0x02, 0x69, 0x64, 0x18, 0x01,
	0x20, 0x02, 0x28, 0x0d, 0x52, 0x02, 0x69, 0x64, 0x12, 0x16, 0x0a, 0x06, 0x6e, 0x65, 0x74, 0x64,
	0x65, 0x76, 0x18, 0x02, 0x20, 0x01, 0x28, 0x09, 0x52, 0x06, 0x6e, 0x65, 0x74, 0x64, 0x65, 0x76,
	0x12, 0x1a, 0x0a, 0x08, 0x64, 0x65, 0x74, 0x61, 0x63, 0x68, 0x65, 0x64, 0x18, 0x03, 0x20, 0x01,
	0x28, 0x08, 0x52, 0x08, 0x64, 0x65, 0x74, 0x61, 0x63, 0x68, 0x65, 0x64, 0x12, 0x13, 0x0a, 0x05,
	0x6e, 0x73, 0x5f, 0x69, 0x64, 0x18, 0x04, 0x20, 0x01, 0x28, 0x0d, 0x52, 0x04, 0x6e, 0x73, 0x49,
	0x64, 0x22, 0x8b, 0x01, 0x0a, 0x0e, 0x74, 0x75, 0x6e, 0x5f, 0x6c, 0x69, 0x6e, 0x6b, 0x5f, 0x65,
	0x6e, 0x74, 0x72, 0x79, 0x12, 0x1b, 0x0a, 0x05, 0x66, 0x6c, 0x61, 0x67, 0x73, 0x18, 0x01, 0x20,
	0x02, 0x28, 0x0d, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x05, 0x66, 0x6c, 0x61, 0x67,
	0x73, 0x12, 0x14, 0x0a, 0x05, 0x6f, 0x77, 0x6e, 0x65, 0x72, 0x18, 0x02, 0x20, 0x02, 0x28, 0x05,
	0x52, 0x05, 0x6f, 0x77, 0x6e, 0x65, 0x72, 0x12, 0x14, 0x0a, 0x05, 0x67, 0x72, 0x6f, 0x75, 0x70,
	0x18, 0x03, 0x20, 0x02, 0x28, 0x05, 0x52, 0x05, 0x67, 0x72, 0x6f, 0x75, 0x70, 0x12, 0x18, 0x0a,
	0x07, 0x76, 0x6e, 0x65, 0x74, 0x68, 0x64, 0x72, 0x18, 0x04, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x07,
	0x76, 0x6e, 0x65, 0x74, 0x68, 0x64, 0x72, 0x12, 0x16, 0x0a, 0x06, 0x73, 0x6e, 0x64, 0x62, 0x75,
	0x66, 0x18, 0x05, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x06, 0x73, 0x6e, 0x64, 0x62, 0x75, 0x66,
}

var (
	file_tun_proto_rawDescOnce sync.Once
	file_tun_proto_rawDescData = file_tun_proto_rawDesc
)

func file_tun_proto_rawDescGZIP() []byte {
	file_tun_proto_rawDescOnce.Do(func() {
		file_tun_proto_rawDescData = protoimpl.X.CompressGZIP(file_tun_proto_rawDescData)
	})
	return file_tun_proto_rawDescData
}

var file_tun_proto_msgTypes = make([]protoimpl.MessageInfo, 2)
var file_tun_proto_goTypes = []interface{}{
	(*TunfileEntry)(nil), // 0: tunfile_entry
	(*TunLinkEntry)(nil), // 1: tun_link_entry
}
var file_tun_proto_depIdxs = []int32{
	0, // [0:0] is the sub-list for method output_type
	0, // [0:0] is the sub-list for method input_type
	0, // [0:0] is the sub-list for extension type_name
	0, // [0:0] is the sub-list for extension extendee
	0, // [0:0] is the sub-list for field type_name
}

func init() { file_tun_proto_init() }
func file_tun_proto_init() {
	if File_tun_proto != nil {
		return
	}
	file_opts_proto_init()
	if !protoimpl.UnsafeEnabled {
		file_tun_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TunfileEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_tun_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TunLinkEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_tun_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   2,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_tun_proto_goTypes,
		DependencyIndexes: file_tun_proto_depIdxs,
		MessageInfos:      file_tun_proto_msgTypes,
	}.Build()
	File_tun_proto = out.File
	file_tun_proto_rawDesc = nil
	file_tun_proto_goTypes = nil
	file_tun_proto_depIdxs = nil
}
