// SPDX-License-Identifier: MIT

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: remap-file-path.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type RemapType int32

const (
	RemapType_LINKED RemapType = 0
	RemapType_GHOST  RemapType = 1
	RemapType_PROCFS RemapType = 2
)

// Enum value maps for RemapType.
var (
	RemapType_name = map[int32]string{
		0: "LINKED",
		1: "GHOST",
		2: "PROCFS",
	}
	RemapType_value = map[string]int32{
		"LINKED": 0,
		"GHOST":  1,
		"PROCFS": 2,
	}
)

func (x RemapType) Enum() *RemapType {
	p := new(RemapType)
	*p = x
	return p
}

func (x RemapType) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (RemapType) Descriptor() protoreflect.EnumDescriptor {
	return file_remap_file_path_proto_enumTypes[0].Descriptor()
}

func (RemapType) Type() protoreflect.EnumType {
	return &file_remap_file_path_proto_enumTypes[0]
}

func (x RemapType) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Do not use.
func (x *RemapType) UnmarshalJSON(b []byte) error {
	num, err := protoimpl.X.UnmarshalJSONEnum(x.Descriptor(), b)
	if err != nil {
		return err
	}
	*x = RemapType(num)
	return nil
}

// Deprecated: Use RemapType.Descriptor instead.
func (RemapType) EnumDescriptor() ([]byte, []int) {
	return file_remap_file_path_proto_rawDescGZIP(), []int{0}
}

type RemapFilePathEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	OrigId    *uint32    `protobuf:"varint,1,req,name=orig_id,json=origId" json:"orig_id,omitempty"`
	RemapId   *uint32    `protobuf:"varint,2,req,name=remap_id,json=remapId" json:"remap_id,omitempty"`
	RemapType *RemapType `protobuf:"varint,3,opt,name=remap_type,json=remapType,enum=RemapType" json:"remap_type,omitempty"`
}

func (x *RemapFilePathEntry) Reset() {
	*x = RemapFilePathEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_remap_file_path_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *RemapFilePathEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RemapFilePathEntry) ProtoMessage() {}

func (x *RemapFilePathEntry) ProtoReflect() protoreflect.Message {
	mi := &file_remap_file_path_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RemapFilePathEntry.ProtoReflect.Descriptor instead.
func (*RemapFilePathEntry) Descriptor() ([]byte, []int) {
	return file_remap_file_path_proto_rawDescGZIP(), []int{0}
}

func (x *RemapFilePathEntry) GetOrigId() uint32 {
	if x != nil && x.OrigId != nil {
		return *x.OrigId
	}
	return 0
}

func (x *RemapFilePathEntry) GetRemapId() uint32 {
	if x != nil && x.RemapId != nil {
		return *x.RemapId
	}
	return 0
}

func (x *RemapFilePathEntry) GetRemapType() RemapType {
	if x != nil && x.RemapType != nil {
		return *x.RemapType
	}
	return RemapType_LINKED
}

var File_remap_file_path_proto protoreflect.FileDescriptor

var file_remap_file_path_proto_rawDesc = []byte{
	0x0a, 0x15, 0x72, 0x65, 0x6d, 0x61, 0x70, 0x2d, 0x66, 0x69, 0x6c, 0x65, 0x2d, 0x70, 0x61, 0x74,
	0x68, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x77, 0x0a, 0x15, 0x72, 0x65, 0x6d, 0x61, 0x70,
	0x5f, 0x66, 0x69, 0x6c, 0x65, 0x5f, 0x70, 0x61, 0x74, 0x68, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79,
	0x12, 0x17, 0x0a, 0x07, 0x6f, 0x72, 0x69, 0x67, 0x5f, 0x69, 0x64, 0x18, 0x01, 0x20, 0x02, 0x28,
	0x0d, 0x52, 0x06, 0x6f, 0x72, 0x69, 0x67, 0x49, 0x64, 0x12, 0x19, 0x0a, 0x08, 0x72, 0x65, 0x6d,
	0x61, 0x70, 0x5f, 0x69, 0x64, 0x18, 0x02, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x07, 0x72, 0x65, 0x6d,
	0x61, 0x70, 0x49, 0x64, 0x12, 0x2a, 0x0a, 0x0a, 0x72, 0x65, 0x6d, 0x61, 0x70, 0x5f, 0x74, 0x79,
	0x70, 0x65, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x0b, 0x2e, 0x72, 0x65, 0x6d, 0x61, 0x70,
	0x5f, 0x74, 0x79, 0x70, 0x65, 0x52, 0x09, 0x72, 0x65, 0x6d, 0x61, 0x70, 0x54, 0x79, 0x70, 0x65,
	0x2a, 0x2f, 0x0a, 0x0a, 0x72, 0x65, 0x6d, 0x61, 0x70, 0x5f, 0x74, 0x79, 0x70, 0x65, 0x12, 0x0a,
	0x0a, 0x06, 0x4c, 0x49, 0x4e, 0x4b, 0x45, 0x44, 0x10, 0x00, 0x12, 0x09, 0x0a, 0x05, 0x47, 0x48,
	0x4f, 0x53, 0x54, 0x10, 0x01, 0x12, 0x0a, 0x0a, 0x06, 0x50, 0x52, 0x4f, 0x43, 0x46, 0x53, 0x10,
	0x02,
}

var (
	file_remap_file_path_proto_rawDescOnce sync.Once
	file_remap_file_path_proto_rawDescData = file_remap_file_path_proto_rawDesc
)

func file_remap_file_path_proto_rawDescGZIP() []byte {
	file_remap_file_path_proto_rawDescOnce.Do(func() {
		file_remap_file_path_proto_rawDescData = protoimpl.X.CompressGZIP(file_remap_file_path_proto_rawDescData)
	})
	return file_remap_file_path_proto_rawDescData
}

var file_remap_file_path_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
var file_remap_file_path_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_remap_file_path_proto_goTypes = []interface{}{
	(RemapType)(0),             // 0: remap_type
	(*RemapFilePathEntry)(nil), // 1: remap_file_path_entry
}
var file_remap_file_path_proto_depIdxs = []int32{
	0, // 0: remap_file_path_entry.remap_type:type_name -> remap_type
	1, // [1:1] is the sub-list for method output_type
	1, // [1:1] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_remap_file_path_proto_init() }
func file_remap_file_path_proto_init() {
	if File_remap_file_path_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_remap_file_path_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*RemapFilePathEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_remap_file_path_proto_rawDesc,
			NumEnums:      1,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_remap_file_path_proto_goTypes,
		DependencyIndexes: file_remap_file_path_proto_depIdxs,
		EnumInfos:         file_remap_file_path_proto_enumTypes,
		MessageInfos:      file_remap_file_path_proto_msgTypes,
	}.Build()
	File_remap_file_path_proto = out.File
	file_remap_file_path_proto_rawDesc = nil
	file_remap_file_path_proto_goTypes = nil
	file_remap_file_path_proto_depIdxs = nil
}
