// SPDX-License-Identifier: MIT

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: cgroup.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type CgroupPerms struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Mode *uint32 `protobuf:"varint,1,req,name=mode" json:"mode,omitempty"`
	Uid  *uint32 `protobuf:"varint,2,req,name=uid" json:"uid,omitempty"`
	Gid  *uint32 `protobuf:"varint,3,req,name=gid" json:"gid,omitempty"`
}

func (x *CgroupPerms) Reset() {
	*x = CgroupPerms{}
	if protoimpl.UnsafeEnabled {
		mi := &file_cgroup_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *CgroupPerms) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CgroupPerms) ProtoMessage() {}

func (x *CgroupPerms) ProtoReflect() protoreflect.Message {
	mi := &file_cgroup_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CgroupPerms.ProtoReflect.Descriptor instead.
func (*CgroupPerms) Descriptor() ([]byte, []int) {
	return file_cgroup_proto_rawDescGZIP(), []int{0}
}

func (x *CgroupPerms) GetMode() uint32 {
	if x != nil && x.Mode != nil {
		return *x.Mode
	}
	return 0
}

func (x *CgroupPerms) GetUid() uint32 {
	if x != nil && x.Uid != nil {
		return *x.Uid
	}
	return 0
}

func (x *CgroupPerms) GetGid() uint32 {
	if x != nil && x.Gid != nil {
		return *x.Gid
	}
	return 0
}

type CgroupPropEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Name  *string      `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
	Value *string      `protobuf:"bytes,2,req,name=value" json:"value,omitempty"`
	Perms *CgroupPerms `protobuf:"bytes,3,opt,name=perms" json:"perms,omitempty"`
}

func (x *CgroupPropEntry) Reset() {
	*x = CgroupPropEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_cgroup_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *CgroupPropEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CgroupPropEntry) ProtoMessage() {}

func (x *CgroupPropEntry) ProtoReflect() protoreflect.Message {
	mi := &file_cgroup_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CgroupPropEntry.ProtoReflect.Descriptor instead.
func (*CgroupPropEntry) Descriptor() ([]byte, []int) {
	return file_cgroup_proto_rawDescGZIP(), []int{1}
}

func (x *CgroupPropEntry) GetName() string {
	if x != nil && x.Name != nil {
		return *x.Name
	}
	return ""
}

func (x *CgroupPropEntry) GetValue() string {
	if x != nil && x.Value != nil {
		return *x.Value
	}
	return ""
}

func (x *CgroupPropEntry) GetPerms() *CgroupPerms {
	if x != nil {
		return x.Perms
	}
	return nil
}

type CgroupDirEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	DirName    *string            `protobuf:"bytes,1,req,name=dir_name,json=dirName" json:"dir_name,omitempty"`
	Children   []*CgroupDirEntry  `protobuf:"bytes,2,rep,name=children" json:"children,omitempty"`
	Properties []*CgroupPropEntry `protobuf:"bytes,3,rep,name=properties" json:"properties,omitempty"`
	DirPerms   *CgroupPerms       `protobuf:"bytes,4,opt,name=dir_perms,json=dirPerms" json:"dir_perms,omitempty"`
}

func (x *CgroupDirEntry) Reset() {
	*x = CgroupDirEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_cgroup_proto_msgTypes[2]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *CgroupDirEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CgroupDirEntry) ProtoMessage() {}

func (x *CgroupDirEntry) ProtoReflect() protoreflect.Message {
	mi := &file_cgroup_proto_msgTypes[2]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CgroupDirEntry.ProtoReflect.Descriptor instead.
func (*CgroupDirEntry) Descriptor() ([]byte, []int) {
	return file_cgroup_proto_rawDescGZIP(), []int{2}
}

func (x *CgroupDirEntry) GetDirName() string {
	if x != nil && x.DirName != nil {
		return *x.DirName
	}
	return ""
}

func (x *CgroupDirEntry) GetChildren() []*CgroupDirEntry {
	if x != nil {
		return x.Children
	}
	return nil
}

func (x *CgroupDirEntry) GetProperties() []*CgroupPropEntry {
	if x != nil {
		return x.Properties
	}
	return nil
}

func (x *CgroupDirEntry) GetDirPerms() *CgroupPerms {
	if x != nil {
		return x.DirPerms
	}
	return nil
}

type CgControllerEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Cnames []string          `protobuf:"bytes,1,rep,name=cnames" json:"cnames,omitempty"`
	Dirs   []*CgroupDirEntry `protobuf:"bytes,2,rep,name=dirs" json:"dirs,omitempty"`
}

func (x *CgControllerEntry) Reset() {
	*x = CgControllerEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_cgroup_proto_msgTypes[3]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *CgControllerEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CgControllerEntry) ProtoMessage() {}

func (x *CgControllerEntry) ProtoReflect() protoreflect.Message {
	mi := &file_cgroup_proto_msgTypes[3]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CgControllerEntry.ProtoReflect.Descriptor instead.
func (*CgControllerEntry) Descriptor() ([]byte, []int) {
	return file_cgroup_proto_rawDescGZIP(), []int{3}
}

func (x *CgControllerEntry) GetCnames() []string {
	if x != nil {
		return x.Cnames
	}
	return nil
}

func (x *CgControllerEntry) GetDirs() []*CgroupDirEntry {
	if x != nil {
		return x.Dirs
	}
	return nil
}

type CgMemberEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Name       *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
	Path       *string `protobuf:"bytes,2,req,name=path" json:"path,omitempty"`
	CgnsPrefix *uint32 `protobuf:"varint,3,opt,name=cgns_prefix,json=cgnsPrefix" json:"cgns_prefix,omitempty"`
}

func (x *CgMemberEntry) Reset() {
	*x = CgMemberEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_cgroup_proto_msgTypes[4]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *CgMemberEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CgMemberEntry) ProtoMessage() {}

func (x *CgMemberEntry) ProtoReflect() protoreflect.Message {
	mi := &file_cgroup_proto_msgTypes[4]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CgMemberEntry.ProtoReflect.Descriptor instead.
func (*CgMemberEntry) Descriptor() ([]byte, []int) {
	return file_cgroup_proto_rawDescGZIP(), []int{4}
}

func (x *CgMemberEntry) GetName() string {
	if x != nil && x.Name != nil {
		return *x.Name
	}
	return ""
}

func (x *CgMemberEntry) GetPath() string {
	if x != nil && x.Path != nil {
		return *x.Path
	}
	return ""
}

func (x *CgMemberEntry) GetCgnsPrefix() uint32 {
	if x != nil && x.CgnsPrefix != nil {
		return *x.CgnsPrefix
	}
	return 0
}

type CgSetEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Id   *uint32          `protobuf:"varint,1,req,name=id" json:"id,omitempty"`
	Ctls []*CgMemberEntry `protobuf:"bytes,2,rep,name=ctls" json:"ctls,omitempty"`
}

func (x *CgSetEntry) Reset() {
	*x = CgSetEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_cgroup_proto_msgTypes[5]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *CgSetEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CgSetEntry) ProtoMessage() {}

func (x *CgSetEntry) ProtoReflect() protoreflect.Message {
	mi := &file_cgroup_proto_msgTypes[5]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CgSetEntry.ProtoReflect.Descriptor instead.
func (*CgSetEntry) Descriptor() ([]byte, []int) {
	return file_cgroup_proto_rawDescGZIP(), []int{5}
}

func (x *CgSetEntry) GetId() uint32 {
	if x != nil && x.Id != nil {
		return *x.Id
	}
	return 0
}

func (x *CgSetEntry) GetCtls() []*CgMemberEntry {
	if x != nil {
		return x.Ctls
	}
	return nil
}

type CgroupEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Sets        []*CgSetEntry        `protobuf:"bytes,1,rep,name=sets" json:"sets,omitempty"`
	Controllers []*CgControllerEntry `protobuf:"bytes,2,rep,name=controllers" json:"controllers,omitempty"`
}

func (x *CgroupEntry) Reset() {
	*x = CgroupEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_cgroup_proto_msgTypes[6]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *CgroupEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CgroupEntry) ProtoMessage() {}

func (x *CgroupEntry) ProtoReflect() protoreflect.Message {
	mi := &file_cgroup_proto_msgTypes[6]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CgroupEntry.ProtoReflect.Descriptor instead.
func (*CgroupEntry) Descriptor() ([]byte, []int) {
	return file_cgroup_proto_rawDescGZIP(), []int{6}
}

func (x *CgroupEntry) GetSets() []*CgSetEntry {
	if x != nil {
		return x.Sets
	}
	return nil
}

func (x *CgroupEntry) GetControllers() []*CgControllerEntry {
	if x != nil {
		return x.Controllers
	}
	return nil
}

var File_cgroup_proto protoreflect.FileDescriptor

var file_cgroup_proto_rawDesc = []byte{
	0x0a, 0x0c, 0x63, 0x67, 0x72, 0x6f, 0x75, 0x70, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x46,
	0x0a, 0x0c, 0x63, 0x67, 0x72, 0x6f, 0x75, 0x70, 0x5f, 0x70, 0x65, 0x72, 0x6d, 0x73, 0x12, 0x12,
	0x0a, 0x04, 0x6d, 0x6f, 0x64, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x04, 0x6d, 0x6f,
	0x64, 0x65, 0x12, 0x10, 0x0a, 0x03, 0x75, 0x69, 0x64, 0x18, 0x02, 0x20, 0x02, 0x28, 0x0d, 0x52,
	0x03, 0x75, 0x69, 0x64, 0x12, 0x10, 0x0a, 0x03, 0x67, 0x69, 0x64, 0x18, 0x03, 0x20, 0x02, 0x28,
	0x0d, 0x52, 0x03, 0x67, 0x69, 0x64, 0x22, 0x62, 0x0a, 0x11, 0x63, 0x67, 0x72, 0x6f, 0x75, 0x70,
	0x5f, 0x70, 0x72, 0x6f, 0x70, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x12, 0x0a, 0x04, 0x6e,
	0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x12,
	0x14, 0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x02, 0x28, 0x09, 0x52, 0x05,
	0x76, 0x61, 0x6c, 0x75, 0x65, 0x12, 0x23, 0x0a, 0x05, 0x70, 0x65, 0x72, 0x6d, 0x73, 0x18, 0x03,
	0x20, 0x01, 0x28, 0x0b, 0x32, 0x0d, 0x2e, 0x63, 0x67, 0x72, 0x6f, 0x75, 0x70, 0x5f, 0x70, 0x65,
	0x72, 0x6d, 0x73, 0x52, 0x05, 0x70, 0x65, 0x72, 0x6d, 0x73, 0x22, 0xbc, 0x01, 0x0a, 0x10, 0x63,
	0x67, 0x72, 0x6f, 0x75, 0x70, 0x5f, 0x64, 0x69, 0x72, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x12,
	0x19, 0x0a, 0x08, 0x64, 0x69, 0x72, 0x5f, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28,
	0x09, 0x52, 0x07, 0x64, 0x69, 0x72, 0x4e, 0x61, 0x6d, 0x65, 0x12, 0x2d, 0x0a, 0x08, 0x63, 0x68,
	0x69, 0x6c, 0x64, 0x72, 0x65, 0x6e, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x11, 0x2e, 0x63,
	0x67, 0x72, 0x6f, 0x75, 0x70, 0x5f, 0x64, 0x69, 0x72, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x52,
	0x08, 0x63, 0x68, 0x69, 0x6c, 0x64, 0x72, 0x65, 0x6e, 0x12, 0x32, 0x0a, 0x0a, 0x70, 0x72, 0x6f,
	0x70, 0x65, 0x72, 0x74, 0x69, 0x65, 0x73, 0x18, 0x03, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x12, 0x2e,
	0x63, 0x67, 0x72, 0x6f, 0x75, 0x70, 0x5f, 0x70, 0x72, 0x6f, 0x70, 0x5f, 0x65, 0x6e, 0x74, 0x72,
	0x79, 0x52, 0x0a, 0x70, 0x72, 0x6f, 0x70, 0x65, 0x72, 0x74, 0x69, 0x65, 0x73, 0x12, 0x2a, 0x0a,
	0x09, 0x64, 0x69, 0x72, 0x5f, 0x70, 0x65, 0x72, 0x6d, 0x73, 0x18, 0x04, 0x20, 0x01, 0x28, 0x0b,
	0x32, 0x0d, 0x2e, 0x63, 0x67, 0x72, 0x6f, 0x75, 0x70, 0x5f, 0x70, 0x65, 0x72, 0x6d, 0x73, 0x52,
	0x08, 0x64, 0x69, 0x72, 0x50, 0x65, 0x72, 0x6d, 0x73, 0x22, 0x54, 0x0a, 0x13, 0x63, 0x67, 0x5f,
	0x63, 0x6f, 0x6e, 0x74, 0x72, 0x6f, 0x6c, 0x6c, 0x65, 0x72, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79,
	0x12, 0x16, 0x0a, 0x06, 0x63, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x18, 0x01, 0x20, 0x03, 0x28, 0x09,
	0x52, 0x06, 0x63, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x12, 0x25, 0x0a, 0x04, 0x64, 0x69, 0x72, 0x73,
	0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x11, 0x2e, 0x63, 0x67, 0x72, 0x6f, 0x75, 0x70, 0x5f,
	0x64, 0x69, 0x72, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x04, 0x64, 0x69, 0x72, 0x73, 0x22,
	0x5a, 0x0a, 0x0f, 0x63, 0x67, 0x5f, 0x6d, 0x65, 0x6d, 0x62, 0x65, 0x72, 0x5f, 0x65, 0x6e, 0x74,
	0x72, 0x79, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09,
	0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x12, 0x0a, 0x04, 0x70, 0x61, 0x74, 0x68, 0x18, 0x02,
	0x20, 0x02, 0x28, 0x09, 0x52, 0x04, 0x70, 0x61, 0x74, 0x68, 0x12, 0x1f, 0x0a, 0x0b, 0x63, 0x67,
	0x6e, 0x73, 0x5f, 0x70, 0x72, 0x65, 0x66, 0x69, 0x78, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0d, 0x52,
	0x0a, 0x63, 0x67, 0x6e, 0x73, 0x50, 0x72, 0x65, 0x66, 0x69, 0x78, 0x22, 0x44, 0x0a, 0x0c, 0x63,
	0x67, 0x5f, 0x73, 0x65, 0x74, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x0e, 0x0a, 0x02, 0x69,
	0x64, 0x18, 0x01, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x02, 0x69, 0x64, 0x12, 0x24, 0x0a, 0x04, 0x63,
	0x74, 0x6c, 0x73, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x10, 0x2e, 0x63, 0x67, 0x5f, 0x6d,
	0x65, 0x6d, 0x62, 0x65, 0x72, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x04, 0x63, 0x74, 0x6c,
	0x73, 0x22, 0x69, 0x0a, 0x0c, 0x63, 0x67, 0x72, 0x6f, 0x75, 0x70, 0x5f, 0x65, 0x6e, 0x74, 0x72,
	0x79, 0x12, 0x21, 0x0a, 0x04, 0x73, 0x65, 0x74, 0x73, 0x18, 0x01, 0x20, 0x03, 0x28, 0x0b, 0x32,
	0x0d, 0x2e, 0x63, 0x67, 0x5f, 0x73, 0x65, 0x74, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x04,
	0x73, 0x65, 0x74, 0x73, 0x12, 0x36, 0x0a, 0x0b, 0x63, 0x6f, 0x6e, 0x74, 0x72, 0x6f, 0x6c, 0x6c,
	0x65, 0x72, 0x73, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x14, 0x2e, 0x63, 0x67, 0x5f, 0x63,
	0x6f, 0x6e, 0x74, 0x72, 0x6f, 0x6c, 0x6c, 0x65, 0x72, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x52,
	0x0b, 0x63, 0x6f, 0x6e, 0x74, 0x72, 0x6f, 0x6c, 0x6c, 0x65, 0x72, 0x73,
}

var (
	file_cgroup_proto_rawDescOnce sync.Once
	file_cgroup_proto_rawDescData = file_cgroup_proto_rawDesc
)

func file_cgroup_proto_rawDescGZIP() []byte {
	file_cgroup_proto_rawDescOnce.Do(func() {
		file_cgroup_proto_rawDescData = protoimpl.X.CompressGZIP(file_cgroup_proto_rawDescData)
	})
	return file_cgroup_proto_rawDescData
}

var file_cgroup_proto_msgTypes = make([]protoimpl.MessageInfo, 7)
var file_cgroup_proto_goTypes = []interface{}{
	(*CgroupPerms)(nil),       // 0: cgroup_perms
	(*CgroupPropEntry)(nil),   // 1: cgroup_prop_entry
	(*CgroupDirEntry)(nil),    // 2: cgroup_dir_entry
	(*CgControllerEntry)(nil), // 3: cg_controller_entry
	(*CgMemberEntry)(nil),     // 4: cg_member_entry
	(*CgSetEntry)(nil),        // 5: cg_set_entry
	(*CgroupEntry)(nil),       // 6: cgroup_entry
}
var file_cgroup_proto_depIdxs = []int32{
	0, // 0: cgroup_prop_entry.perms:type_name -> cgroup_perms
	2, // 1: cgroup_dir_entry.children:type_name -> cgroup_dir_entry
	1, // 2: cgroup_dir_entry.properties:type_name -> cgroup_prop_entry
	0, // 3: cgroup_dir_entry.dir_perms:type_name -> cgroup_perms
	2, // 4: cg_controller_entry.dirs:type_name -> cgroup_dir_entry
	4, // 5: cg_set_entry.ctls:type_name -> cg_member_entry
	5, // 6: cgroup_entry.sets:type_name -> cg_set_entry
	3, // 7: cgroup_entry.controllers:type_name -> cg_controller_entry
	8, // [8:8] is the sub-list for method output_type
	8, // [8:8] is the sub-list for method input_type
	8, // [8:8] is the sub-list for extension type_name
	8, // [8:8] is the sub-list for extension extendee
	0, // [0:8] is the sub-list for field type_name
}

func init() { file_cgroup_proto_init() }
func file_cgroup_proto_init() {
	if File_cgroup_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_cgroup_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*CgroupPerms); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_cgroup_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*CgroupPropEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_cgroup_proto_msgTypes[2].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*CgroupDirEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_cgroup_proto_msgTypes[3].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*CgControllerEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_cgroup_proto_msgTypes[4].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*CgMemberEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_cgroup_proto_msgTypes[5].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*CgSetEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_cgroup_proto_msgTypes[6].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*CgroupEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_cgroup_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   7,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_cgroup_proto_goTypes,
		DependencyIndexes: file_cgroup_proto_depIdxs,
		MessageInfos:      file_cgroup_proto_msgTypes,
	}.Build()
	File_cgroup_proto = out.File
	file_cgroup_proto_rawDesc = nil
	file_cgroup_proto_goTypes = nil
	file_cgroup_proto_depIdxs = nil
}
