// SPDX-License-Identifier: MIT

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: opts.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	descriptorpb "google.golang.org/protobuf/types/descriptorpb"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type CRIU_Opts struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Hex   *bool   `protobuf:"varint,1,opt,name=hex" json:"hex,omitempty"`     // Indicate that CRIT should treat this field as hex.
	Ipadd *bool   `protobuf:"varint,2,opt,name=ipadd" json:"ipadd,omitempty"` // The field is IPv4/v6 address
	Flags *string `protobuf:"bytes,3,opt,name=flags" json:"flags,omitempty"`
	Dev   *bool   `protobuf:"varint,4,opt,name=dev" json:"dev,omitempty"`   // Device major:minor packed
	Odev  *bool   `protobuf:"varint,5,opt,name=odev" json:"odev,omitempty"` // ... in old format
	Dict  *string `protobuf:"bytes,6,opt,name=dict" json:"dict,omitempty"`
	Conv  *string `protobuf:"bytes,7,opt,name=conv" json:"conv,omitempty"`
}

func (x *CRIU_Opts) Reset() {
	*x = CRIU_Opts{}
	if protoimpl.UnsafeEnabled {
		mi := &file_opts_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *CRIU_Opts) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CRIU_Opts) ProtoMessage() {}

func (x *CRIU_Opts) ProtoReflect() protoreflect.Message {
	mi := &file_opts_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CRIU_Opts.ProtoReflect.Descriptor instead.
func (*CRIU_Opts) Descriptor() ([]byte, []int) {
	return file_opts_proto_rawDescGZIP(), []int{0}
}

func (x *CRIU_Opts) GetHex() bool {
	if x != nil && x.Hex != nil {
		return *x.Hex
	}
	return false
}

func (x *CRIU_Opts) GetIpadd() bool {
	if x != nil && x.Ipadd != nil {
		return *x.Ipadd
	}
	return false
}

func (x *CRIU_Opts) GetFlags() string {
	if x != nil && x.Flags != nil {
		return *x.Flags
	}
	return ""
}

func (x *CRIU_Opts) GetDev() bool {
	if x != nil && x.Dev != nil {
		return *x.Dev
	}
	return false
}

func (x *CRIU_Opts) GetOdev() bool {
	if x != nil && x.Odev != nil {
		return *x.Odev
	}
	return false
}

func (x *CRIU_Opts) GetDict() string {
	if x != nil && x.Dict != nil {
		return *x.Dict
	}
	return ""
}

func (x *CRIU_Opts) GetConv() string {
	if x != nil && x.Conv != nil {
		return *x.Conv
	}
	return ""
}

var file_opts_proto_extTypes = []protoimpl.ExtensionInfo{
	{
		ExtendedType:  (*descriptorpb.FieldOptions)(nil),
		ExtensionType: (*CRIU_Opts)(nil),
		Field:         1018,
		Name:          "criu",
		Tag:           "bytes,1018,opt,name=criu",
		Filename:      "opts.proto",
	},
}

// Extension fields to descriptorpb.FieldOptions.
var (
	// Registered unique number to use for all kinds of custom options.
	//
	// optional CRIU_Opts criu = 1018;
	E_Criu = &file_opts_proto_extTypes[0]
)

var File_opts_proto protoreflect.FileDescriptor

var file_opts_proto_rawDesc = []byte{
	0x0a, 0x0a, 0x6f, 0x70, 0x74, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x20, 0x67, 0x6f,
	0x6f, 0x67, 0x6c, 0x65, 0x2f, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x75, 0x66, 0x2f, 0x64, 0x65,
	0x73, 0x63, 0x72, 0x69, 0x70, 0x74, 0x6f, 0x72, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x97,
	0x01, 0x0a, 0x09, 0x43, 0x52, 0x49, 0x55, 0x5f, 0x4f, 0x70, 0x74, 0x73, 0x12, 0x10, 0x0a, 0x03,
	0x68, 0x65, 0x78, 0x18, 0x01, 0x20, 0x01, 0x28, 0x08, 0x52, 0x03, 0x68, 0x65, 0x78, 0x12, 0x14,
	0x0a, 0x05, 0x69, 0x70, 0x61, 0x64, 0x64, 0x18, 0x02, 0x20, 0x01, 0x28, 0x08, 0x52, 0x05, 0x69,
	0x70, 0x61, 0x64, 0x64, 0x12, 0x14, 0x0a, 0x05, 0x66, 0x6c, 0x61, 0x67, 0x73, 0x18, 0x03, 0x20,
	0x01, 0x28, 0x09, 0x52, 0x05, 0x66, 0x6c, 0x61, 0x67, 0x73, 0x12, 0x10, 0x0a, 0x03, 0x64, 0x65,
	0x76, 0x18, 0x04, 0x20, 0x01, 0x28, 0x08, 0x52, 0x03, 0x64, 0x65, 0x76, 0x12, 0x12, 0x0a, 0x04,
	0x6f, 0x64, 0x65, 0x76, 0x18, 0x05, 0x20, 0x01, 0x28, 0x08, 0x52, 0x04, 0x6f, 0x64, 0x65, 0x76,
	0x12, 0x12, 0x0a, 0x04, 0x64, 0x69, 0x63, 0x74, 0x18, 0x06, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04,
	0x64, 0x69, 0x63, 0x74, 0x12, 0x12, 0x0a, 0x04, 0x63, 0x6f, 0x6e, 0x76, 0x18, 0x07, 0x20, 0x01,
	0x28, 0x09, 0x52, 0x04, 0x63, 0x6f, 0x6e, 0x76, 0x3a, 0x3e, 0x0a, 0x04, 0x63, 0x72, 0x69, 0x75,
	0x12, 0x1d, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62,
	0x75, 0x66, 0x2e, 0x46, 0x69, 0x65, 0x6c, 0x64, 0x4f, 0x70, 0x74, 0x69, 0x6f, 0x6e, 0x73, 0x18,
	0xfa, 0x07, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x0a, 0x2e, 0x43, 0x52, 0x49, 0x55, 0x5f, 0x4f, 0x70,
	0x74, 0x73, 0x52, 0x04, 0x63, 0x72, 0x69, 0x75,
}

var (
	file_opts_proto_rawDescOnce sync.Once
	file_opts_proto_rawDescData = file_opts_proto_rawDesc
)

func file_opts_proto_rawDescGZIP() []byte {
	file_opts_proto_rawDescOnce.Do(func() {
		file_opts_proto_rawDescData = protoimpl.X.CompressGZIP(file_opts_proto_rawDescData)
	})
	return file_opts_proto_rawDescData
}

var file_opts_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_opts_proto_goTypes = []interface{}{
	(*CRIU_Opts)(nil),                 // 0: CRIU_Opts
	(*descriptorpb.FieldOptions)(nil), // 1: google.protobuf.FieldOptions
}
var file_opts_proto_depIdxs = []int32{
	1, // 0: criu:extendee -> google.protobuf.FieldOptions
	0, // 1: criu:type_name -> CRIU_Opts
	2, // [2:2] is the sub-list for method output_type
	2, // [2:2] is the sub-list for method input_type
	1, // [1:2] is the sub-list for extension type_name
	0, // [0:1] is the sub-list for extension extendee
	0, // [0:0] is the sub-list for field type_name
}

func init() { file_opts_proto_init() }
func file_opts_proto_init() {
	if File_opts_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_opts_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*CRIU_Opts); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_opts_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 1,
			NumServices:   0,
		},
		GoTypes:           file_opts_proto_goTypes,
		DependencyIndexes: file_opts_proto_depIdxs,
		MessageInfos:      file_opts_proto_msgTypes,
		ExtensionInfos:    file_opts_proto_extTypes,
	}.Build()
	File_opts_proto = out.File
	file_opts_proto_rawDesc = nil
	file_opts_proto_goTypes = nil
	file_opts_proto_depIdxs = nil
}
