// SPDX-License-Identifier: MIT

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: pstree.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type PstreeEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Pid     *uint32  `protobuf:"varint,1,req,name=pid" json:"pid,omitempty"`
	Ppid    *uint32  `protobuf:"varint,2,req,name=ppid" json:"ppid,omitempty"`
	Pgid    *uint32  `protobuf:"varint,3,req,name=pgid" json:"pgid,omitempty"`
	Sid     *uint32  `protobuf:"varint,4,req,name=sid" json:"sid,omitempty"`
	Threads []uint32 `protobuf:"varint,5,rep,name=threads" json:"threads,omitempty"`
}

func (x *PstreeEntry) Reset() {
	*x = PstreeEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_pstree_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *PstreeEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PstreeEntry) ProtoMessage() {}

func (x *PstreeEntry) ProtoReflect() protoreflect.Message {
	mi := &file_pstree_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PstreeEntry.ProtoReflect.Descriptor instead.
func (*PstreeEntry) Descriptor() ([]byte, []int) {
	return file_pstree_proto_rawDescGZIP(), []int{0}
}

func (x *PstreeEntry) GetPid() uint32 {
	if x != nil && x.Pid != nil {
		return *x.Pid
	}
	return 0
}

func (x *PstreeEntry) GetPpid() uint32 {
	if x != nil && x.Ppid != nil {
		return *x.Ppid
	}
	return 0
}

func (x *PstreeEntry) GetPgid() uint32 {
	if x != nil && x.Pgid != nil {
		return *x.Pgid
	}
	return 0
}

func (x *PstreeEntry) GetSid() uint32 {
	if x != nil && x.Sid != nil {
		return *x.Sid
	}
	return 0
}

func (x *PstreeEntry) GetThreads() []uint32 {
	if x != nil {
		return x.Threads
	}
	return nil
}

var File_pstree_proto protoreflect.FileDescriptor

var file_pstree_proto_rawDesc = []byte{
	0x0a, 0x0c, 0x70, 0x73, 0x74, 0x72, 0x65, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x74,
	0x0a, 0x0c, 0x70, 0x73, 0x74, 0x72, 0x65, 0x65, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x10,
	0x0a, 0x03, 0x70, 0x69, 0x64, 0x18, 0x01, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x03, 0x70, 0x69, 0x64,
	0x12, 0x12, 0x0a, 0x04, 0x70, 0x70, 0x69, 0x64, 0x18, 0x02, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x04,
	0x70, 0x70, 0x69, 0x64, 0x12, 0x12, 0x0a, 0x04, 0x70, 0x67, 0x69, 0x64, 0x18, 0x03, 0x20, 0x02,
	0x28, 0x0d, 0x52, 0x04, 0x70, 0x67, 0x69, 0x64, 0x12, 0x10, 0x0a, 0x03, 0x73, 0x69, 0x64, 0x18,
	0x04, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x03, 0x73, 0x69, 0x64, 0x12, 0x18, 0x0a, 0x07, 0x74, 0x68,
	0x72, 0x65, 0x61, 0x64, 0x73, 0x18, 0x05, 0x20, 0x03, 0x28, 0x0d, 0x52, 0x07, 0x74, 0x68, 0x72,
	0x65, 0x61, 0x64, 0x73,
}

var (
	file_pstree_proto_rawDescOnce sync.Once
	file_pstree_proto_rawDescData = file_pstree_proto_rawDesc
)

func file_pstree_proto_rawDescGZIP() []byte {
	file_pstree_proto_rawDescOnce.Do(func() {
		file_pstree_proto_rawDescData = protoimpl.X.CompressGZIP(file_pstree_proto_rawDescData)
	})
	return file_pstree_proto_rawDescData
}

var file_pstree_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_pstree_proto_goTypes = []interface{}{
	(*PstreeEntry)(nil), // 0: pstree_entry
}
var file_pstree_proto_depIdxs = []int32{
	0, // [0:0] is the sub-list for method output_type
	0, // [0:0] is the sub-list for method input_type
	0, // [0:0] is the sub-list for extension type_name
	0, // [0:0] is the sub-list for extension extendee
	0, // [0:0] is the sub-list for field type_name
}

func init() { file_pstree_proto_init() }
func file_pstree_proto_init() {
	if File_pstree_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_pstree_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*PstreeEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_pstree_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_pstree_proto_goTypes,
		DependencyIndexes: file_pstree_proto_depIdxs,
		MessageInfos:      file_pstree_proto_msgTypes,
	}.Build()
	File_pstree_proto = out.File
	file_pstree_proto_rawDesc = nil
	file_pstree_proto_goTypes = nil
	file_pstree_proto_depIdxs = nil
}
