// SPDX-License-Identifier: MIT

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: mm.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type AioRingEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Id      *uint64 `protobuf:"varint,1,req,name=id" json:"id,omitempty"`
	NrReq   *uint32 `protobuf:"varint,2,req,name=nr_req,json=nrReq" json:"nr_req,omitempty"`
	RingLen *uint32 `protobuf:"varint,3,req,name=ring_len,json=ringLen" json:"ring_len,omitempty"`
}

func (x *AioRingEntry) Reset() {
	*x = AioRingEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_mm_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *AioRingEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AioRingEntry) ProtoMessage() {}

func (x *AioRingEntry) ProtoReflect() protoreflect.Message {
	mi := &file_mm_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AioRingEntry.ProtoReflect.Descriptor instead.
func (*AioRingEntry) Descriptor() ([]byte, []int) {
	return file_mm_proto_rawDescGZIP(), []int{0}
}

func (x *AioRingEntry) GetId() uint64 {
	if x != nil && x.Id != nil {
		return *x.Id
	}
	return 0
}

func (x *AioRingEntry) GetNrReq() uint32 {
	if x != nil && x.NrReq != nil {
		return *x.NrReq
	}
	return 0
}

func (x *AioRingEntry) GetRingLen() uint32 {
	if x != nil && x.RingLen != nil {
		return *x.RingLen
	}
	return 0
}

type MmEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	MmStartCode  *uint64         `protobuf:"varint,1,req,name=mm_start_code,json=mmStartCode" json:"mm_start_code,omitempty"`
	MmEndCode    *uint64         `protobuf:"varint,2,req,name=mm_end_code,json=mmEndCode" json:"mm_end_code,omitempty"`
	MmStartData  *uint64         `protobuf:"varint,3,req,name=mm_start_data,json=mmStartData" json:"mm_start_data,omitempty"`
	MmEndData    *uint64         `protobuf:"varint,4,req,name=mm_end_data,json=mmEndData" json:"mm_end_data,omitempty"`
	MmStartStack *uint64         `protobuf:"varint,5,req,name=mm_start_stack,json=mmStartStack" json:"mm_start_stack,omitempty"`
	MmStartBrk   *uint64         `protobuf:"varint,6,req,name=mm_start_brk,json=mmStartBrk" json:"mm_start_brk,omitempty"`
	MmBrk        *uint64         `protobuf:"varint,7,req,name=mm_brk,json=mmBrk" json:"mm_brk,omitempty"`
	MmArgStart   *uint64         `protobuf:"varint,8,req,name=mm_arg_start,json=mmArgStart" json:"mm_arg_start,omitempty"`
	MmArgEnd     *uint64         `protobuf:"varint,9,req,name=mm_arg_end,json=mmArgEnd" json:"mm_arg_end,omitempty"`
	MmEnvStart   *uint64         `protobuf:"varint,10,req,name=mm_env_start,json=mmEnvStart" json:"mm_env_start,omitempty"`
	MmEnvEnd     *uint64         `protobuf:"varint,11,req,name=mm_env_end,json=mmEnvEnd" json:"mm_env_end,omitempty"`
	ExeFileId    *uint32         `protobuf:"varint,12,req,name=exe_file_id,json=exeFileId" json:"exe_file_id,omitempty"`
	MmSavedAuxv  []uint64        `protobuf:"varint,13,rep,name=mm_saved_auxv,json=mmSavedAuxv" json:"mm_saved_auxv,omitempty"`
	Vmas         []*VmaEntry     `protobuf:"bytes,14,rep,name=vmas" json:"vmas,omitempty"`
	Dumpable     *int32          `protobuf:"varint,15,opt,name=dumpable" json:"dumpable,omitempty"`
	Aios         []*AioRingEntry `protobuf:"bytes,16,rep,name=aios" json:"aios,omitempty"`
	ThpDisabled  *bool           `protobuf:"varint,17,opt,name=thp_disabled,json=thpDisabled" json:"thp_disabled,omitempty"`
}

func (x *MmEntry) Reset() {
	*x = MmEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_mm_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *MmEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MmEntry) ProtoMessage() {}

func (x *MmEntry) ProtoReflect() protoreflect.Message {
	mi := &file_mm_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MmEntry.ProtoReflect.Descriptor instead.
func (*MmEntry) Descriptor() ([]byte, []int) {
	return file_mm_proto_rawDescGZIP(), []int{1}
}

func (x *MmEntry) GetMmStartCode() uint64 {
	if x != nil && x.MmStartCode != nil {
		return *x.MmStartCode
	}
	return 0
}

func (x *MmEntry) GetMmEndCode() uint64 {
	if x != nil && x.MmEndCode != nil {
		return *x.MmEndCode
	}
	return 0
}

func (x *MmEntry) GetMmStartData() uint64 {
	if x != nil && x.MmStartData != nil {
		return *x.MmStartData
	}
	return 0
}

func (x *MmEntry) GetMmEndData() uint64 {
	if x != nil && x.MmEndData != nil {
		return *x.MmEndData
	}
	return 0
}

func (x *MmEntry) GetMmStartStack() uint64 {
	if x != nil && x.MmStartStack != nil {
		return *x.MmStartStack
	}
	return 0
}

func (x *MmEntry) GetMmStartBrk() uint64 {
	if x != nil && x.MmStartBrk != nil {
		return *x.MmStartBrk
	}
	return 0
}

func (x *MmEntry) GetMmBrk() uint64 {
	if x != nil && x.MmBrk != nil {
		return *x.MmBrk
	}
	return 0
}

func (x *MmEntry) GetMmArgStart() uint64 {
	if x != nil && x.MmArgStart != nil {
		return *x.MmArgStart
	}
	return 0
}

func (x *MmEntry) GetMmArgEnd() uint64 {
	if x != nil && x.MmArgEnd != nil {
		return *x.MmArgEnd
	}
	return 0
}

func (x *MmEntry) GetMmEnvStart() uint64 {
	if x != nil && x.MmEnvStart != nil {
		return *x.MmEnvStart
	}
	return 0
}

func (x *MmEntry) GetMmEnvEnd() uint64 {
	if x != nil && x.MmEnvEnd != nil {
		return *x.MmEnvEnd
	}
	return 0
}

func (x *MmEntry) GetExeFileId() uint32 {
	if x != nil && x.ExeFileId != nil {
		return *x.ExeFileId
	}
	return 0
}

func (x *MmEntry) GetMmSavedAuxv() []uint64 {
	if x != nil {
		return x.MmSavedAuxv
	}
	return nil
}

func (x *MmEntry) GetVmas() []*VmaEntry {
	if x != nil {
		return x.Vmas
	}
	return nil
}

func (x *MmEntry) GetDumpable() int32 {
	if x != nil && x.Dumpable != nil {
		return *x.Dumpable
	}
	return 0
}

func (x *MmEntry) GetAios() []*AioRingEntry {
	if x != nil {
		return x.Aios
	}
	return nil
}

func (x *MmEntry) GetThpDisabled() bool {
	if x != nil && x.ThpDisabled != nil {
		return *x.ThpDisabled
	}
	return false
}

var File_mm_proto protoreflect.FileDescriptor

var file_mm_proto_rawDesc = []byte{
	0x0a, 0x08, 0x6d, 0x6d, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x0a, 0x6f, 0x70, 0x74, 0x73,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x09, 0x76, 0x6d, 0x61, 0x2e, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x22, 0x52, 0x0a, 0x0e, 0x61, 0x69, 0x6f, 0x5f, 0x72, 0x69, 0x6e, 0x67, 0x5f, 0x65, 0x6e,
	0x74, 0x72, 0x79, 0x12, 0x0e, 0x0a, 0x02, 0x69, 0x64, 0x18, 0x01, 0x20, 0x02, 0x28, 0x04, 0x52,
	0x02, 0x69, 0x64, 0x12, 0x15, 0x0a, 0x06, 0x6e, 0x72, 0x5f, 0x72, 0x65, 0x71, 0x18, 0x02, 0x20,
	0x02, 0x28, 0x0d, 0x52, 0x05, 0x6e, 0x72, 0x52, 0x65, 0x71, 0x12, 0x19, 0x0a, 0x08, 0x72, 0x69,
	0x6e, 0x67, 0x5f, 0x6c, 0x65, 0x6e, 0x18, 0x03, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x07, 0x72, 0x69,
	0x6e, 0x67, 0x4c, 0x65, 0x6e, 0x22, 0x86, 0x05, 0x0a, 0x08, 0x6d, 0x6d, 0x5f, 0x65, 0x6e, 0x74,
	0x72, 0x79, 0x12, 0x29, 0x0a, 0x0d, 0x6d, 0x6d, 0x5f, 0x73, 0x74, 0x61, 0x72, 0x74, 0x5f, 0x63,
	0x6f, 0x64, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28, 0x04, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01,
	0x52, 0x0b, 0x6d, 0x6d, 0x53, 0x74, 0x61, 0x72, 0x74, 0x43, 0x6f, 0x64, 0x65, 0x12, 0x25, 0x0a,
	0x0b, 0x6d, 0x6d, 0x5f, 0x65, 0x6e, 0x64, 0x5f, 0x63, 0x6f, 0x64, 0x65, 0x18, 0x02, 0x20, 0x02,
	0x28, 0x04, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x09, 0x6d, 0x6d, 0x45, 0x6e, 0x64,
	0x43, 0x6f, 0x64, 0x65, 0x12, 0x29, 0x0a, 0x0d, 0x6d, 0x6d, 0x5f, 0x73, 0x74, 0x61, 0x72, 0x74,
	0x5f, 0x64, 0x61, 0x74, 0x61, 0x18, 0x03, 0x20, 0x02, 0x28, 0x04, 0x42, 0x05, 0xd2, 0x3f, 0x02,
	0x08, 0x01, 0x52, 0x0b, 0x6d, 0x6d, 0x53, 0x74, 0x61, 0x72, 0x74, 0x44, 0x61, 0x74, 0x61, 0x12,
	0x25, 0x0a, 0x0b, 0x6d, 0x6d, 0x5f, 0x65, 0x6e, 0x64, 0x5f, 0x64, 0x61, 0x74, 0x61, 0x18, 0x04,
	0x20, 0x02, 0x28, 0x04, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x09, 0x6d, 0x6d, 0x45,
	0x6e, 0x64, 0x44, 0x61, 0x74, 0x61, 0x12, 0x2b, 0x0a, 0x0e, 0x6d, 0x6d, 0x5f, 0x73, 0x74, 0x61,
	0x72, 0x74, 0x5f, 0x73, 0x74, 0x61, 0x63, 0x6b, 0x18, 0x05, 0x20, 0x02, 0x28, 0x04, 0x42, 0x05,
	0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x0c, 0x6d, 0x6d, 0x53, 0x74, 0x61, 0x72, 0x74, 0x53, 0x74,
	0x61, 0x63, 0x6b, 0x12, 0x27, 0x0a, 0x0c, 0x6d, 0x6d, 0x5f, 0x73, 0x74, 0x61, 0x72, 0x74, 0x5f,
	0x62, 0x72, 0x6b, 0x18, 0x06, 0x20, 0x02, 0x28, 0x04, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01,
	0x52, 0x0a, 0x6d, 0x6d, 0x53, 0x74, 0x61, 0x72, 0x74, 0x42, 0x72, 0x6b, 0x12, 0x1c, 0x0a, 0x06,
	0x6d, 0x6d, 0x5f, 0x62, 0x72, 0x6b, 0x18, 0x07, 0x20, 0x02, 0x28, 0x04, 0x42, 0x05, 0xd2, 0x3f,
	0x02, 0x08, 0x01, 0x52, 0x05, 0x6d, 0x6d, 0x42, 0x72, 0x6b, 0x12, 0x27, 0x0a, 0x0c, 0x6d, 0x6d,
	0x5f, 0x61, 0x72, 0x67, 0x5f, 0x73, 0x74, 0x61, 0x72, 0x74, 0x18, 0x08, 0x20, 0x02, 0x28, 0x04,
	0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x0a, 0x6d, 0x6d, 0x41, 0x72, 0x67, 0x53, 0x74,
	0x61, 0x72, 0x74, 0x12, 0x23, 0x0a, 0x0a, 0x6d, 0x6d, 0x5f, 0x61, 0x72, 0x67, 0x5f, 0x65, 0x6e,
	0x64, 0x18, 0x09, 0x20, 0x02, 0x28, 0x04, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x08,
	0x6d, 0x6d, 0x41, 0x72, 0x67, 0x45, 0x6e, 0x64, 0x12, 0x27, 0x0a, 0x0c, 0x6d, 0x6d, 0x5f, 0x65,
	0x6e, 0x76, 0x5f, 0x73, 0x74, 0x61, 0x72, 0x74, 0x18, 0x0a, 0x20, 0x02, 0x28, 0x04, 0x42, 0x05,
	0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x0a, 0x6d, 0x6d, 0x45, 0x6e, 0x76, 0x53, 0x74, 0x61, 0x72,
	0x74, 0x12, 0x23, 0x0a, 0x0a, 0x6d, 0x6d, 0x5f, 0x65, 0x6e, 0x76, 0x5f, 0x65, 0x6e, 0x64, 0x18,
	0x0b, 0x20, 0x02, 0x28, 0x04, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x08, 0x6d, 0x6d,
	0x45, 0x6e, 0x76, 0x45, 0x6e, 0x64, 0x12, 0x1e, 0x0a, 0x0b, 0x65, 0x78, 0x65, 0x5f, 0x66, 0x69,
	0x6c, 0x65, 0x5f, 0x69, 0x64, 0x18, 0x0c, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x09, 0x65, 0x78, 0x65,
	0x46, 0x69, 0x6c, 0x65, 0x49, 0x64, 0x12, 0x22, 0x0a, 0x0d, 0x6d, 0x6d, 0x5f, 0x73, 0x61, 0x76,
	0x65, 0x64, 0x5f, 0x61, 0x75, 0x78, 0x76, 0x18, 0x0d, 0x20, 0x03, 0x28, 0x04, 0x52, 0x0b, 0x6d,
	0x6d, 0x53, 0x61, 0x76, 0x65, 0x64, 0x41, 0x75, 0x78, 0x76, 0x12, 0x1e, 0x0a, 0x04, 0x76, 0x6d,
	0x61, 0x73, 0x18, 0x0e, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x0a, 0x2e, 0x76, 0x6d, 0x61, 0x5f, 0x65,
	0x6e, 0x74, 0x72, 0x79, 0x52, 0x04, 0x76, 0x6d, 0x61, 0x73, 0x12, 0x1a, 0x0a, 0x08, 0x64, 0x75,
	0x6d, 0x70, 0x61, 0x62, 0x6c, 0x65, 0x18, 0x0f, 0x20, 0x01, 0x28, 0x05, 0x52, 0x08, 0x64, 0x75,
	0x6d, 0x70, 0x61, 0x62, 0x6c, 0x65, 0x12, 0x23, 0x0a, 0x04, 0x61, 0x69, 0x6f, 0x73, 0x18, 0x10,
	0x20, 0x03, 0x28, 0x0b, 0x32, 0x0f, 0x2e, 0x61, 0x69, 0x6f, 0x5f, 0x72, 0x69, 0x6e, 0x67, 0x5f,
	0x65, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x04, 0x61, 0x69, 0x6f, 0x73, 0x12, 0x21, 0x0a, 0x0c, 0x74,
	0x68, 0x70, 0x5f, 0x64, 0x69, 0x73, 0x61, 0x62, 0x6c, 0x65, 0x64, 0x18, 0x11, 0x20, 0x01, 0x28,
	0x08, 0x52, 0x0b, 0x74, 0x68, 0x70, 0x44, 0x69, 0x73, 0x61, 0x62, 0x6c, 0x65, 0x64,
}

var (
	file_mm_proto_rawDescOnce sync.Once
	file_mm_proto_rawDescData = file_mm_proto_rawDesc
)

func file_mm_proto_rawDescGZIP() []byte {
	file_mm_proto_rawDescOnce.Do(func() {
		file_mm_proto_rawDescData = protoimpl.X.CompressGZIP(file_mm_proto_rawDescData)
	})
	return file_mm_proto_rawDescData
}

var file_mm_proto_msgTypes = make([]protoimpl.MessageInfo, 2)
var file_mm_proto_goTypes = []interface{}{
	(*AioRingEntry)(nil), // 0: aio_ring_entry
	(*MmEntry)(nil),      // 1: mm_entry
	(*VmaEntry)(nil),     // 2: vma_entry
}
var file_mm_proto_depIdxs = []int32{
	2, // 0: mm_entry.vmas:type_name -> vma_entry
	0, // 1: mm_entry.aios:type_name -> aio_ring_entry
	2, // [2:2] is the sub-list for method output_type
	2, // [2:2] is the sub-list for method input_type
	2, // [2:2] is the sub-list for extension type_name
	2, // [2:2] is the sub-list for extension extendee
	0, // [0:2] is the sub-list for field type_name
}

func init() { file_mm_proto_init() }
func file_mm_proto_init() {
	if File_mm_proto != nil {
		return
	}
	file_opts_proto_init()
	file_vma_proto_init()
	if !protoimpl.UnsafeEnabled {
		file_mm_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*AioRingEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_mm_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*MmEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_mm_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   2,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_mm_proto_goTypes,
		DependencyIndexes: file_mm_proto_depIdxs,
		MessageInfos:      file_mm_proto_msgTypes,
	}.Build()
	File_mm_proto = out.File
	file_mm_proto_rawDesc = nil
	file_mm_proto_goTypes = nil
	file_mm_proto_depIdxs = nil
}
