// SPDX-License-Identifier: MIT

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: timer.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type ItimerEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Isec  *uint64 `protobuf:"varint,1,req,name=isec" json:"isec,omitempty"`
	Iusec *uint64 `protobuf:"varint,2,req,name=iusec" json:"iusec,omitempty"`
	Vsec  *uint64 `protobuf:"varint,3,req,name=vsec" json:"vsec,omitempty"`
	Vusec *uint64 `protobuf:"varint,4,req,name=vusec" json:"vusec,omitempty"`
}

func (x *ItimerEntry) Reset() {
	*x = ItimerEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_timer_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *ItimerEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ItimerEntry) ProtoMessage() {}

func (x *ItimerEntry) ProtoReflect() protoreflect.Message {
	mi := &file_timer_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ItimerEntry.ProtoReflect.Descriptor instead.
func (*ItimerEntry) Descriptor() ([]byte, []int) {
	return file_timer_proto_rawDescGZIP(), []int{0}
}

func (x *ItimerEntry) GetIsec() uint64 {
	if x != nil && x.Isec != nil {
		return *x.Isec
	}
	return 0
}

func (x *ItimerEntry) GetIusec() uint64 {
	if x != nil && x.Iusec != nil {
		return *x.Iusec
	}
	return 0
}

func (x *ItimerEntry) GetVsec() uint64 {
	if x != nil && x.Vsec != nil {
		return *x.Vsec
	}
	return 0
}

func (x *ItimerEntry) GetVusec() uint64 {
	if x != nil && x.Vusec != nil {
		return *x.Vusec
	}
	return 0
}

type PosixTimerEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	ItId           *uint32 `protobuf:"varint,1,req,name=it_id,json=itId" json:"it_id,omitempty"`
	ClockId        *uint32 `protobuf:"varint,2,req,name=clock_id,json=clockId" json:"clock_id,omitempty"`
	SiSigno        *uint32 `protobuf:"varint,3,req,name=si_signo,json=siSigno" json:"si_signo,omitempty"`
	ItSigevNotify  *uint32 `protobuf:"varint,4,req,name=it_sigev_notify,json=itSigevNotify" json:"it_sigev_notify,omitempty"`
	SivalPtr       *uint64 `protobuf:"varint,5,req,name=sival_ptr,json=sivalPtr" json:"sival_ptr,omitempty"`
	Overrun        *uint32 `protobuf:"varint,6,req,name=overrun" json:"overrun,omitempty"`
	Isec           *uint64 `protobuf:"varint,7,req,name=isec" json:"isec,omitempty"`
	Insec          *uint64 `protobuf:"varint,8,req,name=insec" json:"insec,omitempty"`
	Vsec           *uint64 `protobuf:"varint,9,req,name=vsec" json:"vsec,omitempty"`
	Vnsec          *uint64 `protobuf:"varint,10,req,name=vnsec" json:"vnsec,omitempty"`
	NotifyThreadId *int32  `protobuf:"varint,11,opt,name=notify_thread_id,json=notifyThreadId" json:"notify_thread_id,omitempty"`
}

func (x *PosixTimerEntry) Reset() {
	*x = PosixTimerEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_timer_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *PosixTimerEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PosixTimerEntry) ProtoMessage() {}

func (x *PosixTimerEntry) ProtoReflect() protoreflect.Message {
	mi := &file_timer_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PosixTimerEntry.ProtoReflect.Descriptor instead.
func (*PosixTimerEntry) Descriptor() ([]byte, []int) {
	return file_timer_proto_rawDescGZIP(), []int{1}
}

func (x *PosixTimerEntry) GetItId() uint32 {
	if x != nil && x.ItId != nil {
		return *x.ItId
	}
	return 0
}

func (x *PosixTimerEntry) GetClockId() uint32 {
	if x != nil && x.ClockId != nil {
		return *x.ClockId
	}
	return 0
}

func (x *PosixTimerEntry) GetSiSigno() uint32 {
	if x != nil && x.SiSigno != nil {
		return *x.SiSigno
	}
	return 0
}

func (x *PosixTimerEntry) GetItSigevNotify() uint32 {
	if x != nil && x.ItSigevNotify != nil {
		return *x.ItSigevNotify
	}
	return 0
}

func (x *PosixTimerEntry) GetSivalPtr() uint64 {
	if x != nil && x.SivalPtr != nil {
		return *x.SivalPtr
	}
	return 0
}

func (x *PosixTimerEntry) GetOverrun() uint32 {
	if x != nil && x.Overrun != nil {
		return *x.Overrun
	}
	return 0
}

func (x *PosixTimerEntry) GetIsec() uint64 {
	if x != nil && x.Isec != nil {
		return *x.Isec
	}
	return 0
}

func (x *PosixTimerEntry) GetInsec() uint64 {
	if x != nil && x.Insec != nil {
		return *x.Insec
	}
	return 0
}

func (x *PosixTimerEntry) GetVsec() uint64 {
	if x != nil && x.Vsec != nil {
		return *x.Vsec
	}
	return 0
}

func (x *PosixTimerEntry) GetVnsec() uint64 {
	if x != nil && x.Vnsec != nil {
		return *x.Vnsec
	}
	return 0
}

func (x *PosixTimerEntry) GetNotifyThreadId() int32 {
	if x != nil && x.NotifyThreadId != nil {
		return *x.NotifyThreadId
	}
	return 0
}

type TaskTimersEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Real  *ItimerEntry       `protobuf:"bytes,1,req,name=real" json:"real,omitempty"`
	Virt  *ItimerEntry       `protobuf:"bytes,2,req,name=virt" json:"virt,omitempty"`
	Prof  *ItimerEntry       `protobuf:"bytes,3,req,name=prof" json:"prof,omitempty"`
	Posix []*PosixTimerEntry `protobuf:"bytes,4,rep,name=posix" json:"posix,omitempty"`
}

func (x *TaskTimersEntry) Reset() {
	*x = TaskTimersEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_timer_proto_msgTypes[2]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *TaskTimersEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*TaskTimersEntry) ProtoMessage() {}

func (x *TaskTimersEntry) ProtoReflect() protoreflect.Message {
	mi := &file_timer_proto_msgTypes[2]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use TaskTimersEntry.ProtoReflect.Descriptor instead.
func (*TaskTimersEntry) Descriptor() ([]byte, []int) {
	return file_timer_proto_rawDescGZIP(), []int{2}
}

func (x *TaskTimersEntry) GetReal() *ItimerEntry {
	if x != nil {
		return x.Real
	}
	return nil
}

func (x *TaskTimersEntry) GetVirt() *ItimerEntry {
	if x != nil {
		return x.Virt
	}
	return nil
}

func (x *TaskTimersEntry) GetProf() *ItimerEntry {
	if x != nil {
		return x.Prof
	}
	return nil
}

func (x *TaskTimersEntry) GetPosix() []*PosixTimerEntry {
	if x != nil {
		return x.Posix
	}
	return nil
}

var File_timer_proto protoreflect.FileDescriptor

var file_timer_proto_rawDesc = []byte{
	0x0a, 0x0b, 0x74, 0x69, 0x6d, 0x65, 0x72, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x62, 0x0a,
	0x0c, 0x69, 0x74, 0x69, 0x6d, 0x65, 0x72, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x12, 0x0a,
	0x04, 0x69, 0x73, 0x65, 0x63, 0x18, 0x01, 0x20, 0x02, 0x28, 0x04, 0x52, 0x04, 0x69, 0x73, 0x65,
	0x63, 0x12, 0x14, 0x0a, 0x05, 0x69, 0x75, 0x73, 0x65, 0x63, 0x18, 0x02, 0x20, 0x02, 0x28, 0x04,
	0x52, 0x05, 0x69, 0x75, 0x73, 0x65, 0x63, 0x12, 0x12, 0x0a, 0x04, 0x76, 0x73, 0x65, 0x63, 0x18,
	0x03, 0x20, 0x02, 0x28, 0x04, 0x52, 0x04, 0x76, 0x73, 0x65, 0x63, 0x12, 0x14, 0x0a, 0x05, 0x76,
	0x75, 0x73, 0x65, 0x63, 0x18, 0x04, 0x20, 0x02, 0x28, 0x04, 0x52, 0x05, 0x76, 0x75, 0x73, 0x65,
	0x63, 0x22, 0xbb, 0x02, 0x0a, 0x11, 0x70, 0x6f, 0x73, 0x69, 0x78, 0x5f, 0x74, 0x69, 0x6d, 0x65,
	0x72, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x13, 0x0a, 0x05, 0x69, 0x74, 0x5f, 0x69, 0x64,
	0x18, 0x01, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x04, 0x69, 0x74, 0x49, 0x64, 0x12, 0x19, 0x0a, 0x08,
	0x63, 0x6c, 0x6f, 0x63, 0x6b, 0x5f, 0x69, 0x64, 0x18, 0x02, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x07,
	0x63, 0x6c, 0x6f, 0x63, 0x6b, 0x49, 0x64, 0x12, 0x19, 0x0a, 0x08, 0x73, 0x69, 0x5f, 0x73, 0x69,
	0x67, 0x6e, 0x6f, 0x18, 0x03, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x07, 0x73, 0x69, 0x53, 0x69, 0x67,
	0x6e, 0x6f, 0x12, 0x26, 0x0a, 0x0f, 0x69, 0x74, 0x5f, 0x73, 0x69, 0x67, 0x65, 0x76, 0x5f, 0x6e,
	0x6f, 0x74, 0x69, 0x66, 0x79, 0x18, 0x04, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x0d, 0x69, 0x74, 0x53,
	0x69, 0x67, 0x65, 0x76, 0x4e, 0x6f, 0x74, 0x69, 0x66, 0x79, 0x12, 0x1b, 0x0a, 0x09, 0x73, 0x69,
	0x76, 0x61, 0x6c, 0x5f, 0x70, 0x74, 0x72, 0x18, 0x05, 0x20, 0x02, 0x28, 0x04, 0x52, 0x08, 0x73,
	0x69, 0x76, 0x61, 0x6c, 0x50, 0x74, 0x72, 0x12, 0x18, 0x0a, 0x07, 0x6f, 0x76, 0x65, 0x72, 0x72,
	0x75, 0x6e, 0x18, 0x06, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x07, 0x6f, 0x76, 0x65, 0x72, 0x72, 0x75,
	0x6e, 0x12, 0x12, 0x0a, 0x04, 0x69, 0x73, 0x65, 0x63, 0x18, 0x07, 0x20, 0x02, 0x28, 0x04, 0x52,
	0x04, 0x69, 0x73, 0x65, 0x63, 0x12, 0x14, 0x0a, 0x05, 0x69, 0x6e, 0x73, 0x65, 0x63, 0x18, 0x08,
	0x20, 0x02, 0x28, 0x04, 0x52, 0x05, 0x69, 0x6e, 0x73, 0x65, 0x63, 0x12, 0x12, 0x0a, 0x04, 0x76,
	0x73, 0x65, 0x63, 0x18, 0x09, 0x20, 0x02, 0x28, 0x04, 0x52, 0x04, 0x76, 0x73, 0x65, 0x63, 0x12,
	0x14, 0x0a, 0x05, 0x76, 0x6e, 0x73, 0x65, 0x63, 0x18, 0x0a, 0x20, 0x02, 0x28, 0x04, 0x52, 0x05,
	0x76, 0x6e, 0x73, 0x65, 0x63, 0x12, 0x28, 0x0a, 0x10, 0x6e, 0x6f, 0x74, 0x69, 0x66, 0x79, 0x5f,
	0x74, 0x68, 0x72, 0x65, 0x61, 0x64, 0x5f, 0x69, 0x64, 0x18, 0x0b, 0x20, 0x01, 0x28, 0x05, 0x52,
	0x0e, 0x6e, 0x6f, 0x74, 0x69, 0x66, 0x79, 0x54, 0x68, 0x72, 0x65, 0x61, 0x64, 0x49, 0x64, 0x22,
	0xa6, 0x01, 0x0a, 0x11, 0x74, 0x61, 0x73, 0x6b, 0x5f, 0x74, 0x69, 0x6d, 0x65, 0x72, 0x73, 0x5f,
	0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x21, 0x0a, 0x04, 0x72, 0x65, 0x61, 0x6c, 0x18, 0x01, 0x20,
	0x02, 0x28, 0x0b, 0x32, 0x0d, 0x2e, 0x69, 0x74, 0x69, 0x6d, 0x65, 0x72, 0x5f, 0x65, 0x6e, 0x74,
	0x72, 0x79, 0x52, 0x04, 0x72, 0x65, 0x61, 0x6c, 0x12, 0x21, 0x0a, 0x04, 0x76, 0x69, 0x72, 0x74,
	0x18, 0x02, 0x20, 0x02, 0x28, 0x0b, 0x32, 0x0d, 0x2e, 0x69, 0x74, 0x69, 0x6d, 0x65, 0x72, 0x5f,
	0x65, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x04, 0x76, 0x69, 0x72, 0x74, 0x12, 0x21, 0x0a, 0x04, 0x70,
	0x72, 0x6f, 0x66, 0x18, 0x03, 0x20, 0x02, 0x28, 0x0b, 0x32, 0x0d, 0x2e, 0x69, 0x74, 0x69, 0x6d,
	0x65, 0x72, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x04, 0x70, 0x72, 0x6f, 0x66, 0x12, 0x28,
	0x0a, 0x05, 0x70, 0x6f, 0x73, 0x69, 0x78, 0x18, 0x04, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x12, 0x2e,
	0x70, 0x6f, 0x73, 0x69, 0x78, 0x5f, 0x74, 0x69, 0x6d, 0x65, 0x72, 0x5f, 0x65, 0x6e, 0x74, 0x72,
	0x79, 0x52, 0x05, 0x70, 0x6f, 0x73, 0x69, 0x78,
}

var (
	file_timer_proto_rawDescOnce sync.Once
	file_timer_proto_rawDescData = file_timer_proto_rawDesc
)

func file_timer_proto_rawDescGZIP() []byte {
	file_timer_proto_rawDescOnce.Do(func() {
		file_timer_proto_rawDescData = protoimpl.X.CompressGZIP(file_timer_proto_rawDescData)
	})
	return file_timer_proto_rawDescData
}

var file_timer_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_timer_proto_goTypes = []interface{}{
	(*ItimerEntry)(nil),     // 0: itimer_entry
	(*PosixTimerEntry)(nil), // 1: posix_timer_entry
	(*TaskTimersEntry)(nil), // 2: task_timers_entry
}
var file_timer_proto_depIdxs = []int32{
	0, // 0: task_timers_entry.real:type_name -> itimer_entry
	0, // 1: task_timers_entry.virt:type_name -> itimer_entry
	0, // 2: task_timers_entry.prof:type_name -> itimer_entry
	1, // 3: task_timers_entry.posix:type_name -> posix_timer_entry
	4, // [4:4] is the sub-list for method output_type
	4, // [4:4] is the sub-list for method input_type
	4, // [4:4] is the sub-list for extension type_name
	4, // [4:4] is the sub-list for extension extendee
	0, // [0:4] is the sub-list for field type_name
}

func init() { file_timer_proto_init() }
func file_timer_proto_init() {
	if File_timer_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_timer_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*ItimerEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_timer_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*PosixTimerEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_timer_proto_msgTypes[2].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*TaskTimersEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_timer_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   3,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_timer_proto_goTypes,
		DependencyIndexes: file_timer_proto_depIdxs,
		MessageInfos:      file_timer_proto_msgTypes,
	}.Build()
	File_timer_proto = out.File
	file_timer_proto_rawDesc = nil
	file_timer_proto_goTypes = nil
	file_timer_proto_depIdxs = nil
}
