// SPDX-License-Identifier: MIT

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: core-mips.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type UserMipsRegsEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	R0          *uint64 `protobuf:"varint,1,req,name=r0" json:"r0,omitempty"`
	R1          *uint64 `protobuf:"varint,2,req,name=r1" json:"r1,omitempty"`
	R2          *uint64 `protobuf:"varint,3,req,name=r2" json:"r2,omitempty"`
	R3          *uint64 `protobuf:"varint,4,req,name=r3" json:"r3,omitempty"`
	R4          *uint64 `protobuf:"varint,5,req,name=r4" json:"r4,omitempty"`
	R5          *uint64 `protobuf:"varint,6,req,name=r5" json:"r5,omitempty"`
	R6          *uint64 `protobuf:"varint,7,req,name=r6" json:"r6,omitempty"`
	R7          *uint64 `protobuf:"varint,8,req,name=r7" json:"r7,omitempty"`
	R8          *uint64 `protobuf:"varint,9,req,name=r8" json:"r8,omitempty"`
	R9          *uint64 `protobuf:"varint,10,req,name=r9" json:"r9,omitempty"`
	R10         *uint64 `protobuf:"varint,11,req,name=r10" json:"r10,omitempty"`
	R11         *uint64 `protobuf:"varint,12,req,name=r11" json:"r11,omitempty"`
	R12         *uint64 `protobuf:"varint,13,req,name=r12" json:"r12,omitempty"`
	R13         *uint64 `protobuf:"varint,14,req,name=r13" json:"r13,omitempty"`
	R14         *uint64 `protobuf:"varint,15,req,name=r14" json:"r14,omitempty"`
	R15         *uint64 `protobuf:"varint,16,req,name=r15" json:"r15,omitempty"`
	R16         *uint64 `protobuf:"varint,17,req,name=r16" json:"r16,omitempty"`
	R17         *uint64 `protobuf:"varint,18,req,name=r17" json:"r17,omitempty"`
	R18         *uint64 `protobuf:"varint,19,req,name=r18" json:"r18,omitempty"`
	R19         *uint64 `protobuf:"varint,20,req,name=r19" json:"r19,omitempty"`
	R20         *uint64 `protobuf:"varint,21,req,name=r20" json:"r20,omitempty"`
	R21         *uint64 `protobuf:"varint,22,req,name=r21" json:"r21,omitempty"`
	R22         *uint64 `protobuf:"varint,23,req,name=r22" json:"r22,omitempty"`
	R23         *uint64 `protobuf:"varint,24,req,name=r23" json:"r23,omitempty"`
	R24         *uint64 `protobuf:"varint,25,req,name=r24" json:"r24,omitempty"`
	R25         *uint64 `protobuf:"varint,26,req,name=r25" json:"r25,omitempty"`
	R26         *uint64 `protobuf:"varint,27,req,name=r26" json:"r26,omitempty"`
	R27         *uint64 `protobuf:"varint,28,req,name=r27" json:"r27,omitempty"`
	R28         *uint64 `protobuf:"varint,29,req,name=r28" json:"r28,omitempty"`
	R29         *uint64 `protobuf:"varint,30,req,name=r29" json:"r29,omitempty"`
	R30         *uint64 `protobuf:"varint,31,req,name=r30" json:"r30,omitempty"`
	R31         *uint64 `protobuf:"varint,32,req,name=r31" json:"r31,omitempty"`
	Lo          *uint64 `protobuf:"varint,33,req,name=lo" json:"lo,omitempty"`
	Hi          *uint64 `protobuf:"varint,34,req,name=hi" json:"hi,omitempty"`
	Cp0Epc      *uint64 `protobuf:"varint,35,req,name=cp0_epc,json=cp0Epc" json:"cp0_epc,omitempty"`
	Cp0Badvaddr *uint64 `protobuf:"varint,36,req,name=cp0_badvaddr,json=cp0Badvaddr" json:"cp0_badvaddr,omitempty"`
	Cp0Status   *uint64 `protobuf:"varint,37,req,name=cp0_status,json=cp0Status" json:"cp0_status,omitempty"`
	Cp0Cause    *uint64 `protobuf:"varint,38,req,name=cp0_cause,json=cp0Cause" json:"cp0_cause,omitempty"`
}

func (x *UserMipsRegsEntry) Reset() {
	*x = UserMipsRegsEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_core_mips_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *UserMipsRegsEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UserMipsRegsEntry) ProtoMessage() {}

func (x *UserMipsRegsEntry) ProtoReflect() protoreflect.Message {
	mi := &file_core_mips_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UserMipsRegsEntry.ProtoReflect.Descriptor instead.
func (*UserMipsRegsEntry) Descriptor() ([]byte, []int) {
	return file_core_mips_proto_rawDescGZIP(), []int{0}
}

func (x *UserMipsRegsEntry) GetR0() uint64 {
	if x != nil && x.R0 != nil {
		return *x.R0
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR1() uint64 {
	if x != nil && x.R1 != nil {
		return *x.R1
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR2() uint64 {
	if x != nil && x.R2 != nil {
		return *x.R2
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR3() uint64 {
	if x != nil && x.R3 != nil {
		return *x.R3
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR4() uint64 {
	if x != nil && x.R4 != nil {
		return *x.R4
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR5() uint64 {
	if x != nil && x.R5 != nil {
		return *x.R5
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR6() uint64 {
	if x != nil && x.R6 != nil {
		return *x.R6
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR7() uint64 {
	if x != nil && x.R7 != nil {
		return *x.R7
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR8() uint64 {
	if x != nil && x.R8 != nil {
		return *x.R8
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR9() uint64 {
	if x != nil && x.R9 != nil {
		return *x.R9
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR10() uint64 {
	if x != nil && x.R10 != nil {
		return *x.R10
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR11() uint64 {
	if x != nil && x.R11 != nil {
		return *x.R11
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR12() uint64 {
	if x != nil && x.R12 != nil {
		return *x.R12
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR13() uint64 {
	if x != nil && x.R13 != nil {
		return *x.R13
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR14() uint64 {
	if x != nil && x.R14 != nil {
		return *x.R14
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR15() uint64 {
	if x != nil && x.R15 != nil {
		return *x.R15
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR16() uint64 {
	if x != nil && x.R16 != nil {
		return *x.R16
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR17() uint64 {
	if x != nil && x.R17 != nil {
		return *x.R17
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR18() uint64 {
	if x != nil && x.R18 != nil {
		return *x.R18
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR19() uint64 {
	if x != nil && x.R19 != nil {
		return *x.R19
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR20() uint64 {
	if x != nil && x.R20 != nil {
		return *x.R20
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR21() uint64 {
	if x != nil && x.R21 != nil {
		return *x.R21
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR22() uint64 {
	if x != nil && x.R22 != nil {
		return *x.R22
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR23() uint64 {
	if x != nil && x.R23 != nil {
		return *x.R23
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR24() uint64 {
	if x != nil && x.R24 != nil {
		return *x.R24
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR25() uint64 {
	if x != nil && x.R25 != nil {
		return *x.R25
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR26() uint64 {
	if x != nil && x.R26 != nil {
		return *x.R26
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR27() uint64 {
	if x != nil && x.R27 != nil {
		return *x.R27
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR28() uint64 {
	if x != nil && x.R28 != nil {
		return *x.R28
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR29() uint64 {
	if x != nil && x.R29 != nil {
		return *x.R29
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR30() uint64 {
	if x != nil && x.R30 != nil {
		return *x.R30
	}
	return 0
}

func (x *UserMipsRegsEntry) GetR31() uint64 {
	if x != nil && x.R31 != nil {
		return *x.R31
	}
	return 0
}

func (x *UserMipsRegsEntry) GetLo() uint64 {
	if x != nil && x.Lo != nil {
		return *x.Lo
	}
	return 0
}

func (x *UserMipsRegsEntry) GetHi() uint64 {
	if x != nil && x.Hi != nil {
		return *x.Hi
	}
	return 0
}

func (x *UserMipsRegsEntry) GetCp0Epc() uint64 {
	if x != nil && x.Cp0Epc != nil {
		return *x.Cp0Epc
	}
	return 0
}

func (x *UserMipsRegsEntry) GetCp0Badvaddr() uint64 {
	if x != nil && x.Cp0Badvaddr != nil {
		return *x.Cp0Badvaddr
	}
	return 0
}

func (x *UserMipsRegsEntry) GetCp0Status() uint64 {
	if x != nil && x.Cp0Status != nil {
		return *x.Cp0Status
	}
	return 0
}

func (x *UserMipsRegsEntry) GetCp0Cause() uint64 {
	if x != nil && x.Cp0Cause != nil {
		return *x.Cp0Cause
	}
	return 0
}

type UserMipsFpregsEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	R0       *uint64 `protobuf:"varint,1,req,name=r0" json:"r0,omitempty"`
	R1       *uint64 `protobuf:"varint,2,req,name=r1" json:"r1,omitempty"`
	R2       *uint64 `protobuf:"varint,3,req,name=r2" json:"r2,omitempty"`
	R3       *uint64 `protobuf:"varint,4,req,name=r3" json:"r3,omitempty"`
	R4       *uint64 `protobuf:"varint,5,req,name=r4" json:"r4,omitempty"`
	R5       *uint64 `protobuf:"varint,6,req,name=r5" json:"r5,omitempty"`
	R6       *uint64 `protobuf:"varint,7,req,name=r6" json:"r6,omitempty"`
	R7       *uint64 `protobuf:"varint,8,req,name=r7" json:"r7,omitempty"`
	R8       *uint64 `protobuf:"varint,9,req,name=r8" json:"r8,omitempty"`
	R9       *uint64 `protobuf:"varint,10,req,name=r9" json:"r9,omitempty"`
	R10      *uint64 `protobuf:"varint,11,req,name=r10" json:"r10,omitempty"`
	R11      *uint64 `protobuf:"varint,12,req,name=r11" json:"r11,omitempty"`
	R12      *uint64 `protobuf:"varint,13,req,name=r12" json:"r12,omitempty"`
	R13      *uint64 `protobuf:"varint,14,req,name=r13" json:"r13,omitempty"`
	R14      *uint64 `protobuf:"varint,15,req,name=r14" json:"r14,omitempty"`
	R15      *uint64 `protobuf:"varint,16,req,name=r15" json:"r15,omitempty"`
	R16      *uint64 `protobuf:"varint,17,req,name=r16" json:"r16,omitempty"`
	R17      *uint64 `protobuf:"varint,18,req,name=r17" json:"r17,omitempty"`
	R18      *uint64 `protobuf:"varint,19,req,name=r18" json:"r18,omitempty"`
	R19      *uint64 `protobuf:"varint,20,req,name=r19" json:"r19,omitempty"`
	R20      *uint64 `protobuf:"varint,21,req,name=r20" json:"r20,omitempty"`
	R21      *uint64 `protobuf:"varint,22,req,name=r21" json:"r21,omitempty"`
	R22      *uint64 `protobuf:"varint,23,req,name=r22" json:"r22,omitempty"`
	R23      *uint64 `protobuf:"varint,24,req,name=r23" json:"r23,omitempty"`
	R24      *uint64 `protobuf:"varint,25,req,name=r24" json:"r24,omitempty"`
	R25      *uint64 `protobuf:"varint,26,req,name=r25" json:"r25,omitempty"`
	R26      *uint64 `protobuf:"varint,27,req,name=r26" json:"r26,omitempty"`
	R27      *uint64 `protobuf:"varint,28,req,name=r27" json:"r27,omitempty"`
	R28      *uint64 `protobuf:"varint,29,req,name=r28" json:"r28,omitempty"`
	R29      *uint64 `protobuf:"varint,30,req,name=r29" json:"r29,omitempty"`
	R30      *uint64 `protobuf:"varint,31,req,name=r30" json:"r30,omitempty"`
	R31      *uint64 `protobuf:"varint,32,req,name=r31" json:"r31,omitempty"`
	Lo       *uint64 `protobuf:"varint,33,req,name=lo" json:"lo,omitempty"`
	Hi       *uint64 `protobuf:"varint,34,req,name=hi" json:"hi,omitempty"`
	FpuFcr31 *uint32 `protobuf:"varint,35,req,name=fpu_fcr31,json=fpuFcr31" json:"fpu_fcr31,omitempty"`
	FpuId    *uint32 `protobuf:"varint,36,req,name=fpu_id,json=fpuId" json:"fpu_id,omitempty"`
}

func (x *UserMipsFpregsEntry) Reset() {
	*x = UserMipsFpregsEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_core_mips_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *UserMipsFpregsEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UserMipsFpregsEntry) ProtoMessage() {}

func (x *UserMipsFpregsEntry) ProtoReflect() protoreflect.Message {
	mi := &file_core_mips_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UserMipsFpregsEntry.ProtoReflect.Descriptor instead.
func (*UserMipsFpregsEntry) Descriptor() ([]byte, []int) {
	return file_core_mips_proto_rawDescGZIP(), []int{1}
}

func (x *UserMipsFpregsEntry) GetR0() uint64 {
	if x != nil && x.R0 != nil {
		return *x.R0
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR1() uint64 {
	if x != nil && x.R1 != nil {
		return *x.R1
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR2() uint64 {
	if x != nil && x.R2 != nil {
		return *x.R2
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR3() uint64 {
	if x != nil && x.R3 != nil {
		return *x.R3
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR4() uint64 {
	if x != nil && x.R4 != nil {
		return *x.R4
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR5() uint64 {
	if x != nil && x.R5 != nil {
		return *x.R5
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR6() uint64 {
	if x != nil && x.R6 != nil {
		return *x.R6
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR7() uint64 {
	if x != nil && x.R7 != nil {
		return *x.R7
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR8() uint64 {
	if x != nil && x.R8 != nil {
		return *x.R8
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR9() uint64 {
	if x != nil && x.R9 != nil {
		return *x.R9
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR10() uint64 {
	if x != nil && x.R10 != nil {
		return *x.R10
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR11() uint64 {
	if x != nil && x.R11 != nil {
		return *x.R11
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR12() uint64 {
	if x != nil && x.R12 != nil {
		return *x.R12
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR13() uint64 {
	if x != nil && x.R13 != nil {
		return *x.R13
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR14() uint64 {
	if x != nil && x.R14 != nil {
		return *x.R14
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR15() uint64 {
	if x != nil && x.R15 != nil {
		return *x.R15
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR16() uint64 {
	if x != nil && x.R16 != nil {
		return *x.R16
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR17() uint64 {
	if x != nil && x.R17 != nil {
		return *x.R17
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR18() uint64 {
	if x != nil && x.R18 != nil {
		return *x.R18
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR19() uint64 {
	if x != nil && x.R19 != nil {
		return *x.R19
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR20() uint64 {
	if x != nil && x.R20 != nil {
		return *x.R20
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR21() uint64 {
	if x != nil && x.R21 != nil {
		return *x.R21
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR22() uint64 {
	if x != nil && x.R22 != nil {
		return *x.R22
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR23() uint64 {
	if x != nil && x.R23 != nil {
		return *x.R23
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR24() uint64 {
	if x != nil && x.R24 != nil {
		return *x.R24
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR25() uint64 {
	if x != nil && x.R25 != nil {
		return *x.R25
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR26() uint64 {
	if x != nil && x.R26 != nil {
		return *x.R26
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR27() uint64 {
	if x != nil && x.R27 != nil {
		return *x.R27
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR28() uint64 {
	if x != nil && x.R28 != nil {
		return *x.R28
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR29() uint64 {
	if x != nil && x.R29 != nil {
		return *x.R29
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR30() uint64 {
	if x != nil && x.R30 != nil {
		return *x.R30
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetR31() uint64 {
	if x != nil && x.R31 != nil {
		return *x.R31
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetLo() uint64 {
	if x != nil && x.Lo != nil {
		return *x.Lo
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetHi() uint64 {
	if x != nil && x.Hi != nil {
		return *x.Hi
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetFpuFcr31() uint32 {
	if x != nil && x.FpuFcr31 != nil {
		return *x.FpuFcr31
	}
	return 0
}

func (x *UserMipsFpregsEntry) GetFpuId() uint32 {
	if x != nil && x.FpuId != nil {
		return *x.FpuId
	}
	return 0
}

type ThreadInfoMips struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	ClearTidAddr *uint64              `protobuf:"varint,1,req,name=clear_tid_addr,json=clearTidAddr" json:"clear_tid_addr,omitempty"`
	Tls          *uint64              `protobuf:"varint,2,req,name=tls" json:"tls,omitempty"`
	Gpregs       *UserMipsRegsEntry   `protobuf:"bytes,3,req,name=gpregs" json:"gpregs,omitempty"`
	Fpregs       *UserMipsFpregsEntry `protobuf:"bytes,4,req,name=fpregs" json:"fpregs,omitempty"`
}

func (x *ThreadInfoMips) Reset() {
	*x = ThreadInfoMips{}
	if protoimpl.UnsafeEnabled {
		mi := &file_core_mips_proto_msgTypes[2]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *ThreadInfoMips) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ThreadInfoMips) ProtoMessage() {}

func (x *ThreadInfoMips) ProtoReflect() protoreflect.Message {
	mi := &file_core_mips_proto_msgTypes[2]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ThreadInfoMips.ProtoReflect.Descriptor instead.
func (*ThreadInfoMips) Descriptor() ([]byte, []int) {
	return file_core_mips_proto_rawDescGZIP(), []int{2}
}

func (x *ThreadInfoMips) GetClearTidAddr() uint64 {
	if x != nil && x.ClearTidAddr != nil {
		return *x.ClearTidAddr
	}
	return 0
}

func (x *ThreadInfoMips) GetTls() uint64 {
	if x != nil && x.Tls != nil {
		return *x.Tls
	}
	return 0
}

func (x *ThreadInfoMips) GetGpregs() *UserMipsRegsEntry {
	if x != nil {
		return x.Gpregs
	}
	return nil
}

func (x *ThreadInfoMips) GetFpregs() *UserMipsFpregsEntry {
	if x != nil {
		return x.Fpregs
	}
	return nil
}

var File_core_mips_proto protoreflect.FileDescriptor

var file_core_mips_proto_rawDesc = []byte{
	0x0a, 0x0f, 0x63, 0x6f, 0x72, 0x65, 0x2d, 0x6d, 0x69, 0x70, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x1a, 0x0a, 0x6f, 0x70, 0x74, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0xda, 0x05,
	0x0a, 0x14, 0x75, 0x73, 0x65, 0x72, 0x5f, 0x6d, 0x69, 0x70, 0x73, 0x5f, 0x72, 0x65, 0x67, 0x73,
	0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x30, 0x18, 0x01, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x02, 0x72, 0x30, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x31, 0x18, 0x02, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x02, 0x72, 0x31, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x32, 0x18, 0x03, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x02, 0x72, 0x32, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x33, 0x18, 0x04, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x02, 0x72, 0x33, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x34, 0x18, 0x05, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x02, 0x72, 0x34, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x35, 0x18, 0x06, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x02, 0x72, 0x35, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x36, 0x18, 0x07, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x02, 0x72, 0x36, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x37, 0x18, 0x08, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x02, 0x72, 0x37, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x38, 0x18, 0x09, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x02, 0x72, 0x38, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x39, 0x18, 0x0a, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x02, 0x72, 0x39, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x30, 0x18, 0x0b, 0x20,
	0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x30, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x31, 0x18,
	0x0c, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x31, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31,
	0x32, 0x18, 0x0d, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x32, 0x12, 0x10, 0x0a, 0x03,
	0x72, 0x31, 0x33, 0x18, 0x0e, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x33, 0x12, 0x10,
	0x0a, 0x03, 0x72, 0x31, 0x34, 0x18, 0x0f, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x34,
	0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x35, 0x18, 0x10, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72,
	0x31, 0x35, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x36, 0x18, 0x11, 0x20, 0x02, 0x28, 0x04, 0x52,
	0x03, 0x72, 0x31, 0x36, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x37, 0x18, 0x12, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x03, 0x72, 0x31, 0x37, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x38, 0x18, 0x13, 0x20,
	0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x38, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x39, 0x18,
	0x14, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x39, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32,
	0x30, 0x18, 0x15, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x30, 0x12, 0x10, 0x0a, 0x03,
	0x72, 0x32, 0x31, 0x18, 0x16, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x31, 0x12, 0x10,
	0x0a, 0x03, 0x72, 0x32, 0x32, 0x18, 0x17, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x32,
	0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x33, 0x18, 0x18, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72,
	0x32, 0x33, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x34, 0x18, 0x19, 0x20, 0x02, 0x28, 0x04, 0x52,
	0x03, 0x72, 0x32, 0x34, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x35, 0x18, 0x1a, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x03, 0x72, 0x32, 0x35, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x36, 0x18, 0x1b, 0x20,
	0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x36, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x37, 0x18,
	0x1c, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x37, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32,
	0x38, 0x18, 0x1d, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x38, 0x12, 0x10, 0x0a, 0x03,
	0x72, 0x32, 0x39, 0x18, 0x1e, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x39, 0x12, 0x10,
	0x0a, 0x03, 0x72, 0x33, 0x30, 0x18, 0x1f, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x33, 0x30,
	0x12, 0x10, 0x0a, 0x03, 0x72, 0x33, 0x31, 0x18, 0x20, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72,
	0x33, 0x31, 0x12, 0x0e, 0x0a, 0x02, 0x6c, 0x6f, 0x18, 0x21, 0x20, 0x02, 0x28, 0x04, 0x52, 0x02,
	0x6c, 0x6f, 0x12, 0x0e, 0x0a, 0x02, 0x68, 0x69, 0x18, 0x22, 0x20, 0x02, 0x28, 0x04, 0x52, 0x02,
	0x68, 0x69, 0x12, 0x17, 0x0a, 0x07, 0x63, 0x70, 0x30, 0x5f, 0x65, 0x70, 0x63, 0x18, 0x23, 0x20,
	0x02, 0x28, 0x04, 0x52, 0x06, 0x63, 0x70, 0x30, 0x45, 0x70, 0x63, 0x12, 0x21, 0x0a, 0x0c, 0x63,
	0x70, 0x30, 0x5f, 0x62, 0x61, 0x64, 0x76, 0x61, 0x64, 0x64, 0x72, 0x18, 0x24, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x0b, 0x63, 0x70, 0x30, 0x42, 0x61, 0x64, 0x76, 0x61, 0x64, 0x64, 0x72, 0x12, 0x1d,
	0x0a, 0x0a, 0x63, 0x70, 0x30, 0x5f, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x18, 0x25, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x09, 0x63, 0x70, 0x30, 0x53, 0x74, 0x61, 0x74, 0x75, 0x73, 0x12, 0x1b, 0x0a,
	0x09, 0x63, 0x70, 0x30, 0x5f, 0x63, 0x61, 0x75, 0x73, 0x65, 0x18, 0x26, 0x20, 0x02, 0x28, 0x04,
	0x52, 0x08, 0x63, 0x70, 0x30, 0x43, 0x61, 0x75, 0x73, 0x65, 0x22, 0x98, 0x05, 0x0a, 0x16, 0x75,
	0x73, 0x65, 0x72, 0x5f, 0x6d, 0x69, 0x70, 0x73, 0x5f, 0x66, 0x70, 0x72, 0x65, 0x67, 0x73, 0x5f,
	0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x30, 0x18, 0x01, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x02, 0x72, 0x30, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x31, 0x18, 0x02, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x02, 0x72, 0x31, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x32, 0x18, 0x03, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x02, 0x72, 0x32, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x33, 0x18, 0x04, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x02, 0x72, 0x33, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x34, 0x18, 0x05, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x02, 0x72, 0x34, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x35, 0x18, 0x06, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x02, 0x72, 0x35, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x36, 0x18, 0x07, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x02, 0x72, 0x36, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x37, 0x18, 0x08, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x02, 0x72, 0x37, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x38, 0x18, 0x09, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x02, 0x72, 0x38, 0x12, 0x0e, 0x0a, 0x02, 0x72, 0x39, 0x18, 0x0a, 0x20, 0x02, 0x28,
	0x04, 0x52, 0x02, 0x72, 0x39, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x30, 0x18, 0x0b, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x30, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x31, 0x18, 0x0c,
	0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x31, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x32,
	0x18, 0x0d, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x32, 0x12, 0x10, 0x0a, 0x03, 0x72,
	0x31, 0x33, 0x18, 0x0e, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x33, 0x12, 0x10, 0x0a,
	0x03, 0x72, 0x31, 0x34, 0x18, 0x0f, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x34, 0x12,
	0x10, 0x0a, 0x03, 0x72, 0x31, 0x35, 0x18, 0x10, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31,
	0x35, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x36, 0x18, 0x11, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03,
	0x72, 0x31, 0x36, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x37, 0x18, 0x12, 0x20, 0x02, 0x28, 0x04,
	0x52, 0x03, 0x72, 0x31, 0x37, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x38, 0x18, 0x13, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x38, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x31, 0x39, 0x18, 0x14,
	0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x31, 0x39, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x30,
	0x18, 0x15, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x30, 0x12, 0x10, 0x0a, 0x03, 0x72,
	0x32, 0x31, 0x18, 0x16, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x31, 0x12, 0x10, 0x0a,
	0x03, 0x72, 0x32, 0x32, 0x18, 0x17, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x32, 0x12,
	0x10, 0x0a, 0x03, 0x72, 0x32, 0x33, 0x18, 0x18, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32,
	0x33, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x34, 0x18, 0x19, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03,
	0x72, 0x32, 0x34, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x35, 0x18, 0x1a, 0x20, 0x02, 0x28, 0x04,
	0x52, 0x03, 0x72, 0x32, 0x35, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x36, 0x18, 0x1b, 0x20, 0x02,
	0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x36, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x37, 0x18, 0x1c,
	0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x37, 0x12, 0x10, 0x0a, 0x03, 0x72, 0x32, 0x38,
	0x18, 0x1d, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x38, 0x12, 0x10, 0x0a, 0x03, 0x72,
	0x32, 0x39, 0x18, 0x1e, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x32, 0x39, 0x12, 0x10, 0x0a,
	0x03, 0x72, 0x33, 0x30, 0x18, 0x1f, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x33, 0x30, 0x12,
	0x10, 0x0a, 0x03, 0x72, 0x33, 0x31, 0x18, 0x20, 0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x72, 0x33,
	0x31, 0x12, 0x0e, 0x0a, 0x02, 0x6c, 0x6f, 0x18, 0x21, 0x20, 0x02, 0x28, 0x04, 0x52, 0x02, 0x6c,
	0x6f, 0x12, 0x0e, 0x0a, 0x02, 0x68, 0x69, 0x18, 0x22, 0x20, 0x02, 0x28, 0x04, 0x52, 0x02, 0x68,
	0x69, 0x12, 0x1b, 0x0a, 0x09, 0x66, 0x70, 0x75, 0x5f, 0x66, 0x63, 0x72, 0x33, 0x31, 0x18, 0x23,
	0x20, 0x02, 0x28, 0x0d, 0x52, 0x08, 0x66, 0x70, 0x75, 0x46, 0x63, 0x72, 0x33, 0x31, 0x12, 0x15,
	0x0a, 0x06, 0x66, 0x70, 0x75, 0x5f, 0x69, 0x64, 0x18, 0x24, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x05,
	0x66, 0x70, 0x75, 0x49, 0x64, 0x22, 0xbf, 0x01, 0x0a, 0x10, 0x74, 0x68, 0x72, 0x65, 0x61, 0x64,
	0x5f, 0x69, 0x6e, 0x66, 0x6f, 0x5f, 0x6d, 0x69, 0x70, 0x73, 0x12, 0x2b, 0x0a, 0x0e, 0x63, 0x6c,
	0x65, 0x61, 0x72, 0x5f, 0x74, 0x69, 0x64, 0x5f, 0x61, 0x64, 0x64, 0x72, 0x18, 0x01, 0x20, 0x02,
	0x28, 0x04, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x0c, 0x63, 0x6c, 0x65, 0x61, 0x72,
	0x54, 0x69, 0x64, 0x41, 0x64, 0x64, 0x72, 0x12, 0x10, 0x0a, 0x03, 0x74, 0x6c, 0x73, 0x18, 0x02,
	0x20, 0x02, 0x28, 0x04, 0x52, 0x03, 0x74, 0x6c, 0x73, 0x12, 0x34, 0x0a, 0x06, 0x67, 0x70, 0x72,
	0x65, 0x67, 0x73, 0x18, 0x03, 0x20, 0x02, 0x28, 0x0b, 0x32, 0x15, 0x2e, 0x75, 0x73, 0x65, 0x72,
	0x5f, 0x6d, 0x69, 0x70, 0x73, 0x5f, 0x72, 0x65, 0x67, 0x73, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79,
	0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x06, 0x67, 0x70, 0x72, 0x65, 0x67, 0x73, 0x12,
	0x36, 0x0a, 0x06, 0x66, 0x70, 0x72, 0x65, 0x67, 0x73, 0x18, 0x04, 0x20, 0x02, 0x28, 0x0b, 0x32,
	0x17, 0x2e, 0x75, 0x73, 0x65, 0x72, 0x5f, 0x6d, 0x69, 0x70, 0x73, 0x5f, 0x66, 0x70, 0x72, 0x65,
	0x67, 0x73, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52,
	0x06, 0x66, 0x70, 0x72, 0x65, 0x67, 0x73,
}

var (
	file_core_mips_proto_rawDescOnce sync.Once
	file_core_mips_proto_rawDescData = file_core_mips_proto_rawDesc
)

func file_core_mips_proto_rawDescGZIP() []byte {
	file_core_mips_proto_rawDescOnce.Do(func() {
		file_core_mips_proto_rawDescData = protoimpl.X.CompressGZIP(file_core_mips_proto_rawDescData)
	})
	return file_core_mips_proto_rawDescData
}

var file_core_mips_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_core_mips_proto_goTypes = []interface{}{
	(*UserMipsRegsEntry)(nil),   // 0: user_mips_regs_entry
	(*UserMipsFpregsEntry)(nil), // 1: user_mips_fpregs_entry
	(*ThreadInfoMips)(nil),      // 2: thread_info_mips
}
var file_core_mips_proto_depIdxs = []int32{
	0, // 0: thread_info_mips.gpregs:type_name -> user_mips_regs_entry
	1, // 1: thread_info_mips.fpregs:type_name -> user_mips_fpregs_entry
	2, // [2:2] is the sub-list for method output_type
	2, // [2:2] is the sub-list for method input_type
	2, // [2:2] is the sub-list for extension type_name
	2, // [2:2] is the sub-list for extension extendee
	0, // [0:2] is the sub-list for field type_name
}

func init() { file_core_mips_proto_init() }
func file_core_mips_proto_init() {
	if File_core_mips_proto != nil {
		return
	}
	file_opts_proto_init()
	if !protoimpl.UnsafeEnabled {
		file_core_mips_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*UserMipsRegsEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_core_mips_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*UserMipsFpregsEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_core_mips_proto_msgTypes[2].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*ThreadInfoMips); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_core_mips_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   3,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_core_mips_proto_goTypes,
		DependencyIndexes: file_core_mips_proto_depIdxs,
		MessageInfos:      file_core_mips_proto_msgTypes,
	}.Build()
	File_core_mips_proto = out.File
	file_core_mips_proto_rawDesc = nil
	file_core_mips_proto_goTypes = nil
	file_core_mips_proto_depIdxs = nil
}
