// SPDX-License-Identifier: MIT

syntax = "proto2";

import "criu-core.proto";

enum lsmtype {
	NO_LSM		= 0;
	SELINUX		= 1;
	APPARMOR	= 2;
}

message inventory_entry {
	required uint32			img_version	= 1;
	optional bool			fdinfo_per_id	= 2;
	optional task_kobj_ids_entry	root_ids	= 3;
	optional bool			ns_per_id	= 4;
	optional uint32			root_cg_set	= 5;
	optional lsmtype		lsmtype		= 6;
	optional uint64			dump_uptime	= 8;
	optional uint32			pre_dump_mode	= 9;
	optional bool			tcp_close	= 10;
	optional uint32			network_lock_method	= 11;
}
