// SPDX-License-Identifier: MIT

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: utsns.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type UtsnsEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Nodename   *string `protobuf:"bytes,1,req,name=nodename" json:"nodename,omitempty"`
	Domainname *string `protobuf:"bytes,2,req,name=domainname" json:"domainname,omitempty"`
}

func (x *UtsnsEntry) Reset() {
	*x = UtsnsEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_utsns_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *UtsnsEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UtsnsEntry) ProtoMessage() {}

func (x *UtsnsEntry) ProtoReflect() protoreflect.Message {
	mi := &file_utsns_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UtsnsEntry.ProtoReflect.Descriptor instead.
func (*UtsnsEntry) Descriptor() ([]byte, []int) {
	return file_utsns_proto_rawDescGZIP(), []int{0}
}

func (x *UtsnsEntry) GetNodename() string {
	if x != nil && x.Nodename != nil {
		return *x.Nodename
	}
	return ""
}

func (x *UtsnsEntry) GetDomainname() string {
	if x != nil && x.Domainname != nil {
		return *x.Domainname
	}
	return ""
}

var File_utsns_proto protoreflect.FileDescriptor

var file_utsns_proto_rawDesc = []byte{
	0x0a, 0x0b, 0x75, 0x74, 0x73, 0x6e, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x49, 0x0a,
	0x0b, 0x75, 0x74, 0x73, 0x6e, 0x73, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x1a, 0x0a, 0x08,
	0x6e, 0x6f, 0x64, 0x65, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x08,
	0x6e, 0x6f, 0x64, 0x65, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x1e, 0x0a, 0x0a, 0x64, 0x6f, 0x6d, 0x61,
	0x69, 0x6e, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x02, 0x20, 0x02, 0x28, 0x09, 0x52, 0x0a, 0x64, 0x6f,
	0x6d, 0x61, 0x69, 0x6e, 0x6e, 0x61, 0x6d, 0x65,
}

var (
	file_utsns_proto_rawDescOnce sync.Once
	file_utsns_proto_rawDescData = file_utsns_proto_rawDesc
)

func file_utsns_proto_rawDescGZIP() []byte {
	file_utsns_proto_rawDescOnce.Do(func() {
		file_utsns_proto_rawDescData = protoimpl.X.CompressGZIP(file_utsns_proto_rawDescData)
	})
	return file_utsns_proto_rawDescData
}

var file_utsns_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_utsns_proto_goTypes = []interface{}{
	(*UtsnsEntry)(nil), // 0: utsns_entry
}
var file_utsns_proto_depIdxs = []int32{
	0, // [0:0] is the sub-list for method output_type
	0, // [0:0] is the sub-list for method input_type
	0, // [0:0] is the sub-list for extension type_name
	0, // [0:0] is the sub-list for extension extendee
	0, // [0:0] is the sub-list for field type_name
}

func init() { file_utsns_proto_init() }
func file_utsns_proto_init() {
	if File_utsns_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_utsns_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*UtsnsEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_utsns_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_utsns_proto_goTypes,
		DependencyIndexes: file_utsns_proto_depIdxs,
		MessageInfos:      file_utsns_proto_msgTypes,
	}.Build()
	File_utsns_proto = out.File
	file_utsns_proto_rawDesc = nil
	file_utsns_proto_goTypes = nil
	file_utsns_proto_depIdxs = nil
}
