// Code generated by magicgen. DO NOT EDIT.

package magic

type MagicMap struct {
	ByName  map[string]uint64
	ByValue map[uint64]string
}

func LoadMagic() MagicMap {
	magicMap := MagicMap{
		ByName:  make(map[string]uint64),
		ByValue: make(map[uint64]string),
	}
	magicMap.ByName["APPARMOR"] = 1497509959
	magicMap.ByValue[1497509959] = "APPARMOR"
	magicMap.ByName["AUTOFS"] = 1228224835
	magicMap.ByValue[1228224835] = "AUTOFS"
	magicMap.ByName["BINFMT_MISC"] = 1731474211
	magicMap.ByValue[1731474211] = "BINFMT_MISC"
	magicMap.ByName["BPFMAP_DATA"] = 1681014835
	magicMap.ByValue[1681014835] = "BPFMAP_DATA"
	magicMap.ByName["BPFMAP_FILE"] = 1464885570
	magicMap.ByValue[1464885570] = "BPFMAP_FILE"
	magicMap.ByName["CGROUP"] = 1496855344
	magicMap.ByValue[1496855344] = "CGROUP"
	magicMap.ByName["CORE"] = 1426405447
	magicMap.ByValue[1426405447] = "CORE"
	magicMap.ByName["CPUINFO"] = 1631600659
	magicMap.ByValue[1631600659] = "CPUINFO"
	magicMap.ByName["CREDS"] = 1409430855
	magicMap.ByValue[1409430855] = "CREDS"
	magicMap.ByName["CRTOOLS_IMAGES_V1_1"] = 2
	magicMap.ByValue[2] = "CRTOOLS_IMAGES_V1_1"
	magicMap.ByName["EVENTFD_FILE"] = 1146238754
	magicMap.ByValue[1146238754] = "EVENTFD_FILE"
	magicMap.ByName["EVENTPOLL_FILE"] = 1157773400
	magicMap.ByValue[1157773400] = "EVENTPOLL_FILE"
	magicMap.ByName["EVENTPOLL_TFD"] = 1145255750
	magicMap.ByValue[1145255750] = "EVENTPOLL_TFD"
	magicMap.ByName["EXT_FILES"] = 1495619137
	magicMap.ByValue[1495619137] = "EXT_FILES"
	magicMap.ByName["FANOTIFY_FILE"] = 1426678050
	magicMap.ByValue[1426678050] = "FANOTIFY_FILE"
	magicMap.ByName["FANOTIFY_MARK"] = 1448108085
	magicMap.ByValue[1448108085] = "FANOTIFY_MARK"
	magicMap.ByName["FDINFO"] = 1445017394
	magicMap.ByValue[1445017394] = "FDINFO"
	magicMap.ByName["FIFO_DATA"] = 1496526932
	magicMap.ByValue[1496526932] = "FIFO_DATA"
	magicMap.ByName["FIFO"] = 1479952697
	magicMap.ByValue[1479952697] = "FIFO"
	magicMap.ByName["FILES"] = 1445998904
	magicMap.ByValue[1445998904] = "FILES"
	magicMap.ByName["FILE_LOCKS"] = 1412576790
	magicMap.ByValue[1412576790] = "FILE_LOCKS"
	magicMap.ByName["FS"] = 1363163410
	magicMap.ByValue[1363163410] = "FS"
	magicMap.ByName["GHOST_FILE"] = 1381512709
	magicMap.ByValue[1381512709] = "GHOST_FILE"
	magicMap.ByName["IDS"] = 1413685296
	magicMap.ByValue[1413685296] = "IDS"
	magicMap.ByName["IMG_COMMON"] = 1414939417
	magicMap.ByValue[1414939417] = "IMG_COMMON"
	magicMap.ByName["IMG_SERVICE"] = 1427134784
	magicMap.ByValue[1427134784] = "IMG_SERVICE"
	magicMap.ByName["INETSK"] = 1447311441
	magicMap.ByValue[1447311441] = "INETSK"
	magicMap.ByName["INOTIFY_FILE"] = 1212302385
	magicMap.ByValue[1212302385] = "INOTIFY_FILE"
	magicMap.ByName["INOTIFY_WD"] = 1414930441
	magicMap.ByValue[1414930441] = "INOTIFY_WD"
	magicMap.ByName["INVENTORY"] = 1479618838
	magicMap.ByValue[1479618838] = "INVENTORY"
	magicMap.ByName["IPCNS_MSG"] = 1430599479
	magicMap.ByValue[1430599479] = "IPCNS_MSG"
	magicMap.ByName["IPCNS_SEM"] = 1498886169
	magicMap.ByValue[1498886169] = "IPCNS_SEM"
	magicMap.ByName["IPCNS_SHM"] = 1177038916
	magicMap.ByValue[1177038916] = "IPCNS_SHM"
	magicMap.ByName["IPC_VAR"] = 1393643527
	magicMap.ByValue[1393643527] = "IPC_VAR"
	magicMap.ByName["IRMAP_CACHE"] = 1459634265
	magicMap.ByValue[1459634265] = "IRMAP_CACHE"
	magicMap.ByName["ITIMERS"] = 1464221782
	magicMap.ByValue[1464221782] = "ITIMERS"
	magicMap.ByName["KDAT"] = 1459762264
	magicMap.ByValue[1459762264] = "KDAT"
	magicMap.ByName["MEMFD_INODE"] = 1212495001
	magicMap.ByValue[1212495001] = "MEMFD_INODE"
	magicMap.ByName["MM"] = 1464412192
	magicMap.ByValue[1464412192] = "MM"
	magicMap.ByName["MNTS"] = 1431714088
	magicMap.ByValue[1431714088] = "MNTS"
	magicMap.ByName["NETDEV"] = 1463236945
	magicMap.ByValue[1463236945] = "NETDEV"
	magicMap.ByName["NETLINK_SK"] = 1476417044
	magicMap.ByValue[1476417044] = "NETLINK_SK"
	magicMap.ByName["NETNS"] = 1435711314
	magicMap.ByValue[1435711314] = "NETNS"
	magicMap.ByName["NS_FILES"] = 1631141905
	magicMap.ByValue[1631141905] = "NS_FILES"
	magicMap.ByName["PACKETSK"] = 1615152664
	magicMap.ByValue[1615152664] = "PACKETSK"
	magicMap.ByName["PAGEMAP"] = 1443381285
	magicMap.ByValue[1443381285] = "PAGEMAP"
	magicMap.ByName["PIDNS"] = 1628795686
	magicMap.ByValue[1628795686] = "PIDNS"
	magicMap.ByName["PIPES_DATA"] = 1447376649
	magicMap.ByValue[1447376649] = "PIPES_DATA"
	magicMap.ByName["PIPES"] = 1448162645
	magicMap.ByValue[1448162645] = "PIPES"
	magicMap.ByName["POSIX_TIMERS"] = 1382037847
	magicMap.ByValue[1382037847] = "POSIX_TIMERS"
	magicMap.ByName["PSTREE"] = 1344745520
	magicMap.ByValue[1344745520] = "PSTREE"
	magicMap.ByName["REG_FILES"] = 1345730102
	magicMap.ByValue[1345730102] = "REG_FILES"
	magicMap.ByName["REMAP_FPATH"] = 1494432084
	magicMap.ByValue[1494432084] = "REMAP_FPATH"
	magicMap.ByName["RLIMIT"] = 1460746533
	magicMap.ByValue[1460746533] = "RLIMIT"
	magicMap.ByName["SECCOMP"] = 1681993801
	magicMap.ByValue[1681993801] = "SECCOMP"
	magicMap.ByName["SIGACT"] = 1429488129
	magicMap.ByValue[1429488129] = "SIGACT"
	magicMap.ByName["SIGNALFD"] = 1462908960
	magicMap.ByValue[1462908960] = "SIGNALFD"
	magicMap.ByName["SIGNAL"] = 1495619143
	magicMap.ByValue[1495619143] = "SIGNAL"
	magicMap.ByName["SK_QUEUES"] = 1445347366
	magicMap.ByValue[1445347366] = "SK_QUEUES"
	magicMap.ByName["STATS"] = 1460220678
	magicMap.ByValue[1460220678] = "STATS"
	magicMap.ByName["TCP_STREAM"] = 1363563782
	magicMap.ByValue[1363563782] = "TCP_STREAM"
	magicMap.ByName["TIMENS"] = 1125205043
	magicMap.ByValue[1125205043] = "TIMENS"
	magicMap.ByName["TIMERFD"] = 1346975506
	magicMap.ByValue[1346975506] = "TIMERFD"
	magicMap.ByName["TTY_DATA"] = 1497444390
	magicMap.ByValue[1497444390] = "TTY_DATA"
	magicMap.ByName["TTY_FILES"] = 1497575461
	magicMap.ByValue[1497575461] = "TTY_FILES"
	magicMap.ByName["TTY_INFO"] = 1497706550
	magicMap.ByValue[1497706550] = "TTY_INFO"
	magicMap.ByName["TUNFILE"] = 1460942673
	magicMap.ByValue[1460942673] = "TUNFILE"
	magicMap.ByName["UNIXSK"] = 1412905283
	magicMap.ByValue[1412905283] = "UNIXSK"
	magicMap.ByName["USERNS"] = 1430735110
	magicMap.ByValue[1430735110] = "USERNS"
	magicMap.ByName["UTSNS"] = 1413952003
	magicMap.ByValue[1413952003] = "UTSNS"
	magicMap.ByName["VMAS"] = 1410479927
	magicMap.ByValue[1410479927] = "VMAS"
	return magicMap
}
