// SPDX-License-Identifier: MIT

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.28.1
// 	protoc        v3.21.5
// source: mnt.proto

package images

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type Fstype int32

const (
	Fstype_UNSUPPORTED Fstype = 0
	Fstype_PROC        Fstype = 1
	Fstype_SYSFS       Fstype = 2
	Fstype_DEVTMPFS    Fstype = 3
	Fstype_BINFMT_MISC Fstype = 4
	Fstype_TMPFS       Fstype = 5
	Fstype_DEVPTS      Fstype = 6
	Fstype_SIMFS       Fstype = 7
	Fstype_PSTORE      Fstype = 8
	Fstype_SECURITYFS  Fstype = 9
	Fstype_FUSECTL     Fstype = 10
	Fstype_DEBUGFS     Fstype = 11
	Fstype_CGROUP      Fstype = 12
	Fstype_AUFS        Fstype = 13
	Fstype_MQUEUE      Fstype = 14
	Fstype_FUSE        Fstype = 15
	Fstype_AUTO        Fstype = 16
	Fstype_OVERLAYFS   Fstype = 17
	Fstype_AUTOFS      Fstype = 18
	Fstype_TRACEFS     Fstype = 19
	Fstype_CGROUP2     Fstype = 23
)

// Enum value maps for Fstype.
var (
	Fstype_name = map[int32]string{
		0:  "UNSUPPORTED",
		1:  "PROC",
		2:  "SYSFS",
		3:  "DEVTMPFS",
		4:  "BINFMT_MISC",
		5:  "TMPFS",
		6:  "DEVPTS",
		7:  "SIMFS",
		8:  "PSTORE",
		9:  "SECURITYFS",
		10: "FUSECTL",
		11: "DEBUGFS",
		12: "CGROUP",
		13: "AUFS",
		14: "MQUEUE",
		15: "FUSE",
		16: "AUTO",
		17: "OVERLAYFS",
		18: "AUTOFS",
		19: "TRACEFS",
		23: "CGROUP2",
	}
	Fstype_value = map[string]int32{
		"UNSUPPORTED": 0,
		"PROC":        1,
		"SYSFS":       2,
		"DEVTMPFS":    3,
		"BINFMT_MISC": 4,
		"TMPFS":       5,
		"DEVPTS":      6,
		"SIMFS":       7,
		"PSTORE":      8,
		"SECURITYFS":  9,
		"FUSECTL":     10,
		"DEBUGFS":     11,
		"CGROUP":      12,
		"AUFS":        13,
		"MQUEUE":      14,
		"FUSE":        15,
		"AUTO":        16,
		"OVERLAYFS":   17,
		"AUTOFS":      18,
		"TRACEFS":     19,
		"CGROUP2":     23,
	}
)

func (x Fstype) Enum() *Fstype {
	p := new(Fstype)
	*p = x
	return p
}

func (x Fstype) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Fstype) Descriptor() protoreflect.EnumDescriptor {
	return file_mnt_proto_enumTypes[0].Descriptor()
}

func (Fstype) Type() protoreflect.EnumType {
	return &file_mnt_proto_enumTypes[0]
}

func (x Fstype) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Do not use.
func (x *Fstype) UnmarshalJSON(b []byte) error {
	num, err := protoimpl.X.UnmarshalJSONEnum(x.Descriptor(), b)
	if err != nil {
		return err
	}
	*x = Fstype(num)
	return nil
}

// Deprecated: Use Fstype.Descriptor instead.
func (Fstype) EnumDescriptor() ([]byte, []int) {
	return file_mnt_proto_rawDescGZIP(), []int{0}
}

type MntEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Fstype          *uint32 `protobuf:"varint,1,req,name=fstype" json:"fstype,omitempty"`
	MntId           *uint32 `protobuf:"varint,2,req,name=mnt_id,json=mntId" json:"mnt_id,omitempty"`
	RootDev         *uint32 `protobuf:"varint,3,req,name=root_dev,json=rootDev" json:"root_dev,omitempty"`
	ParentMntId     *uint32 `protobuf:"varint,4,req,name=parent_mnt_id,json=parentMntId" json:"parent_mnt_id,omitempty"`
	Flags           *uint32 `protobuf:"varint,5,req,name=flags" json:"flags,omitempty"`
	Root            *string `protobuf:"bytes,6,req,name=root" json:"root,omitempty"`
	Mountpoint      *string `protobuf:"bytes,7,req,name=mountpoint" json:"mountpoint,omitempty"`
	Source          *string `protobuf:"bytes,8,req,name=source" json:"source,omitempty"`
	Options         *string `protobuf:"bytes,9,req,name=options" json:"options,omitempty"`
	SharedId        *uint32 `protobuf:"varint,10,opt,name=shared_id,json=sharedId" json:"shared_id,omitempty"`
	MasterId        *uint32 `protobuf:"varint,11,opt,name=master_id,json=masterId" json:"master_id,omitempty"`
	WithPlugin      *bool   `protobuf:"varint,12,opt,name=with_plugin,json=withPlugin" json:"with_plugin,omitempty"`
	ExtMount        *bool   `protobuf:"varint,13,opt,name=ext_mount,json=extMount" json:"ext_mount,omitempty"`
	Fsname          *string `protobuf:"bytes,14,opt,name=fsname" json:"fsname,omitempty"`
	InternalSharing *bool   `protobuf:"varint,15,opt,name=internal_sharing,json=internalSharing" json:"internal_sharing,omitempty"`
	Deleted         *bool   `protobuf:"varint,16,opt,name=deleted" json:"deleted,omitempty"`
	SbFlags         *uint32 `protobuf:"varint,17,opt,name=sb_flags,json=sbFlags" json:"sb_flags,omitempty"`
	// user defined mapping for external mount
	ExtKey *string `protobuf:"bytes,18,opt,name=ext_key,json=extKey" json:"ext_key,omitempty"`
}

func (x *MntEntry) Reset() {
	*x = MntEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_mnt_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *MntEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MntEntry) ProtoMessage() {}

func (x *MntEntry) ProtoReflect() protoreflect.Message {
	mi := &file_mnt_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MntEntry.ProtoReflect.Descriptor instead.
func (*MntEntry) Descriptor() ([]byte, []int) {
	return file_mnt_proto_rawDescGZIP(), []int{0}
}

func (x *MntEntry) GetFstype() uint32 {
	if x != nil && x.Fstype != nil {
		return *x.Fstype
	}
	return 0
}

func (x *MntEntry) GetMntId() uint32 {
	if x != nil && x.MntId != nil {
		return *x.MntId
	}
	return 0
}

func (x *MntEntry) GetRootDev() uint32 {
	if x != nil && x.RootDev != nil {
		return *x.RootDev
	}
	return 0
}

func (x *MntEntry) GetParentMntId() uint32 {
	if x != nil && x.ParentMntId != nil {
		return *x.ParentMntId
	}
	return 0
}

func (x *MntEntry) GetFlags() uint32 {
	if x != nil && x.Flags != nil {
		return *x.Flags
	}
	return 0
}

func (x *MntEntry) GetRoot() string {
	if x != nil && x.Root != nil {
		return *x.Root
	}
	return ""
}

func (x *MntEntry) GetMountpoint() string {
	if x != nil && x.Mountpoint != nil {
		return *x.Mountpoint
	}
	return ""
}

func (x *MntEntry) GetSource() string {
	if x != nil && x.Source != nil {
		return *x.Source
	}
	return ""
}

func (x *MntEntry) GetOptions() string {
	if x != nil && x.Options != nil {
		return *x.Options
	}
	return ""
}

func (x *MntEntry) GetSharedId() uint32 {
	if x != nil && x.SharedId != nil {
		return *x.SharedId
	}
	return 0
}

func (x *MntEntry) GetMasterId() uint32 {
	if x != nil && x.MasterId != nil {
		return *x.MasterId
	}
	return 0
}

func (x *MntEntry) GetWithPlugin() bool {
	if x != nil && x.WithPlugin != nil {
		return *x.WithPlugin
	}
	return false
}

func (x *MntEntry) GetExtMount() bool {
	if x != nil && x.ExtMount != nil {
		return *x.ExtMount
	}
	return false
}

func (x *MntEntry) GetFsname() string {
	if x != nil && x.Fsname != nil {
		return *x.Fsname
	}
	return ""
}

func (x *MntEntry) GetInternalSharing() bool {
	if x != nil && x.InternalSharing != nil {
		return *x.InternalSharing
	}
	return false
}

func (x *MntEntry) GetDeleted() bool {
	if x != nil && x.Deleted != nil {
		return *x.Deleted
	}
	return false
}

func (x *MntEntry) GetSbFlags() uint32 {
	if x != nil && x.SbFlags != nil {
		return *x.SbFlags
	}
	return 0
}

func (x *MntEntry) GetExtKey() string {
	if x != nil && x.ExtKey != nil {
		return *x.ExtKey
	}
	return ""
}

var File_mnt_proto protoreflect.FileDescriptor

var file_mnt_proto_rawDesc = []byte{
	0x0a, 0x09, 0x6d, 0x6e, 0x74, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x0a, 0x6f, 0x70, 0x74,
	0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x93, 0x04, 0x0a, 0x09, 0x6d, 0x6e, 0x74, 0x5f,
	0x65, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x16, 0x0a, 0x06, 0x66, 0x73, 0x74, 0x79, 0x70, 0x65, 0x18,
	0x01, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x06, 0x66, 0x73, 0x74, 0x79, 0x70, 0x65, 0x12, 0x15, 0x0a,
	0x06, 0x6d, 0x6e, 0x74, 0x5f, 0x69, 0x64, 0x18, 0x02, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x05, 0x6d,
	0x6e, 0x74, 0x49, 0x64, 0x12, 0x20, 0x0a, 0x08, 0x72, 0x6f, 0x6f, 0x74, 0x5f, 0x64, 0x65, 0x76,
	0x18, 0x03, 0x20, 0x02, 0x28, 0x0d, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x20, 0x01, 0x52, 0x07, 0x72,
	0x6f, 0x6f, 0x74, 0x44, 0x65, 0x76, 0x12, 0x22, 0x0a, 0x0d, 0x70, 0x61, 0x72, 0x65, 0x6e, 0x74,
	0x5f, 0x6d, 0x6e, 0x74, 0x5f, 0x69, 0x64, 0x18, 0x04, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x0b, 0x70,
	0x61, 0x72, 0x65, 0x6e, 0x74, 0x4d, 0x6e, 0x74, 0x49, 0x64, 0x12, 0x1b, 0x0a, 0x05, 0x66, 0x6c,
	0x61, 0x67, 0x73, 0x18, 0x05, 0x20, 0x02, 0x28, 0x0d, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01,
	0x52, 0x05, 0x66, 0x6c, 0x61, 0x67, 0x73, 0x12, 0x12, 0x0a, 0x04, 0x72, 0x6f, 0x6f, 0x74, 0x18,
	0x06, 0x20, 0x02, 0x28, 0x09, 0x52, 0x04, 0x72, 0x6f, 0x6f, 0x74, 0x12, 0x1e, 0x0a, 0x0a, 0x6d,
	0x6f, 0x75, 0x6e, 0x74, 0x70, 0x6f, 0x69, 0x6e, 0x74, 0x18, 0x07, 0x20, 0x02, 0x28, 0x09, 0x52,
	0x0a, 0x6d, 0x6f, 0x75, 0x6e, 0x74, 0x70, 0x6f, 0x69, 0x6e, 0x74, 0x12, 0x16, 0x0a, 0x06, 0x73,
	0x6f, 0x75, 0x72, 0x63, 0x65, 0x18, 0x08, 0x20, 0x02, 0x28, 0x09, 0x52, 0x06, 0x73, 0x6f, 0x75,
	0x72, 0x63, 0x65, 0x12, 0x18, 0x0a, 0x07, 0x6f, 0x70, 0x74, 0x69, 0x6f, 0x6e, 0x73, 0x18, 0x09,
	0x20, 0x02, 0x28, 0x09, 0x52, 0x07, 0x6f, 0x70, 0x74, 0x69, 0x6f, 0x6e, 0x73, 0x12, 0x1b, 0x0a,
	0x09, 0x73, 0x68, 0x61, 0x72, 0x65, 0x64, 0x5f, 0x69, 0x64, 0x18, 0x0a, 0x20, 0x01, 0x28, 0x0d,
	0x52, 0x08, 0x73, 0x68, 0x61, 0x72, 0x65, 0x64, 0x49, 0x64, 0x12, 0x1b, 0x0a, 0x09, 0x6d, 0x61,
	0x73, 0x74, 0x65, 0x72, 0x5f, 0x69, 0x64, 0x18, 0x0b, 0x20, 0x01, 0x28, 0x0d, 0x52, 0x08, 0x6d,
	0x61, 0x73, 0x74, 0x65, 0x72, 0x49, 0x64, 0x12, 0x1f, 0x0a, 0x0b, 0x77, 0x69, 0x74, 0x68, 0x5f,
	0x70, 0x6c, 0x75, 0x67, 0x69, 0x6e, 0x18, 0x0c, 0x20, 0x01, 0x28, 0x08, 0x52, 0x0a, 0x77, 0x69,
	0x74, 0x68, 0x50, 0x6c, 0x75, 0x67, 0x69, 0x6e, 0x12, 0x1b, 0x0a, 0x09, 0x65, 0x78, 0x74, 0x5f,
	0x6d, 0x6f, 0x75, 0x6e, 0x74, 0x18, 0x0d, 0x20, 0x01, 0x28, 0x08, 0x52, 0x08, 0x65, 0x78, 0x74,
	0x4d, 0x6f, 0x75, 0x6e, 0x74, 0x12, 0x16, 0x0a, 0x06, 0x66, 0x73, 0x6e, 0x61, 0x6d, 0x65, 0x18,
	0x0e, 0x20, 0x01, 0x28, 0x09, 0x52, 0x06, 0x66, 0x73, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x29, 0x0a,
	0x10, 0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e, 0x61, 0x6c, 0x5f, 0x73, 0x68, 0x61, 0x72, 0x69, 0x6e,
	0x67, 0x18, 0x0f, 0x20, 0x01, 0x28, 0x08, 0x52, 0x0f, 0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e, 0x61,
	0x6c, 0x53, 0x68, 0x61, 0x72, 0x69, 0x6e, 0x67, 0x12, 0x18, 0x0a, 0x07, 0x64, 0x65, 0x6c, 0x65,
	0x74, 0x65, 0x64, 0x18, 0x10, 0x20, 0x01, 0x28, 0x08, 0x52, 0x07, 0x64, 0x65, 0x6c, 0x65, 0x74,
	0x65, 0x64, 0x12, 0x20, 0x0a, 0x08, 0x73, 0x62, 0x5f, 0x66, 0x6c, 0x61, 0x67, 0x73, 0x18, 0x11,
	0x20, 0x01, 0x28, 0x0d, 0x42, 0x05, 0xd2, 0x3f, 0x02, 0x08, 0x01, 0x52, 0x07, 0x73, 0x62, 0x46,
	0x6c, 0x61, 0x67, 0x73, 0x12, 0x17, 0x0a, 0x07, 0x65, 0x78, 0x74, 0x5f, 0x6b, 0x65, 0x79, 0x18,
	0x12, 0x20, 0x01, 0x28, 0x09, 0x52, 0x06, 0x65, 0x78, 0x74, 0x4b, 0x65, 0x79, 0x2a, 0x90, 0x02,
	0x0a, 0x06, 0x66, 0x73, 0x74, 0x79, 0x70, 0x65, 0x12, 0x0f, 0x0a, 0x0b, 0x55, 0x4e, 0x53, 0x55,
	0x50, 0x50, 0x4f, 0x52, 0x54, 0x45, 0x44, 0x10, 0x00, 0x12, 0x08, 0x0a, 0x04, 0x50, 0x52, 0x4f,
	0x43, 0x10, 0x01, 0x12, 0x09, 0x0a, 0x05, 0x53, 0x59, 0x53, 0x46, 0x53, 0x10, 0x02, 0x12, 0x0c,
	0x0a, 0x08, 0x44, 0x45, 0x56, 0x54, 0x4d, 0x50, 0x46, 0x53, 0x10, 0x03, 0x12, 0x0f, 0x0a, 0x0b,
	0x42, 0x49, 0x4e, 0x46, 0x4d, 0x54, 0x5f, 0x4d, 0x49, 0x53, 0x43, 0x10, 0x04, 0x12, 0x09, 0x0a,
	0x05, 0x54, 0x4d, 0x50, 0x46, 0x53, 0x10, 0x05, 0x12, 0x0a, 0x0a, 0x06, 0x44, 0x45, 0x56, 0x50,
	0x54, 0x53, 0x10, 0x06, 0x12, 0x09, 0x0a, 0x05, 0x53, 0x49, 0x4d, 0x46, 0x53, 0x10, 0x07, 0x12,
	0x0a, 0x0a, 0x06, 0x50, 0x53, 0x54, 0x4f, 0x52, 0x45, 0x10, 0x08, 0x12, 0x0e, 0x0a, 0x0a, 0x53,
	0x45, 0x43, 0x55, 0x52, 0x49, 0x54, 0x59, 0x46, 0x53, 0x10, 0x09, 0x12, 0x0b, 0x0a, 0x07, 0x46,
	0x55, 0x53, 0x45, 0x43, 0x54, 0x4c, 0x10, 0x0a, 0x12, 0x0b, 0x0a, 0x07, 0x44, 0x45, 0x42, 0x55,
	0x47, 0x46, 0x53, 0x10, 0x0b, 0x12, 0x0a, 0x0a, 0x06, 0x43, 0x47, 0x52, 0x4f, 0x55, 0x50, 0x10,
	0x0c, 0x12, 0x08, 0x0a, 0x04, 0x41, 0x55, 0x46, 0x53, 0x10, 0x0d, 0x12, 0x0a, 0x0a, 0x06, 0x4d,
	0x51, 0x55, 0x45, 0x55, 0x45, 0x10, 0x0e, 0x12, 0x08, 0x0a, 0x04, 0x46, 0x55, 0x53, 0x45, 0x10,
	0x0f, 0x12, 0x08, 0x0a, 0x04, 0x41, 0x55, 0x54, 0x4f, 0x10, 0x10, 0x12, 0x0d, 0x0a, 0x09, 0x4f,
	0x56, 0x45, 0x52, 0x4c, 0x41, 0x59, 0x46, 0x53, 0x10, 0x11, 0x12, 0x0a, 0x0a, 0x06, 0x41, 0x55,
	0x54, 0x4f, 0x46, 0x53, 0x10, 0x12, 0x12, 0x0b, 0x0a, 0x07, 0x54, 0x52, 0x41, 0x43, 0x45, 0x46,
	0x53, 0x10, 0x13, 0x12, 0x0b, 0x0a, 0x07, 0x43, 0x47, 0x52, 0x4f, 0x55, 0x50, 0x32, 0x10, 0x17,
}

var (
	file_mnt_proto_rawDescOnce sync.Once
	file_mnt_proto_rawDescData = file_mnt_proto_rawDesc
)

func file_mnt_proto_rawDescGZIP() []byte {
	file_mnt_proto_rawDescOnce.Do(func() {
		file_mnt_proto_rawDescData = protoimpl.X.CompressGZIP(file_mnt_proto_rawDescData)
	})
	return file_mnt_proto_rawDescData
}

var file_mnt_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
var file_mnt_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_mnt_proto_goTypes = []interface{}{
	(Fstype)(0),      // 0: fstype
	(*MntEntry)(nil), // 1: mnt_entry
}
var file_mnt_proto_depIdxs = []int32{
	0, // [0:0] is the sub-list for method output_type
	0, // [0:0] is the sub-list for method input_type
	0, // [0:0] is the sub-list for extension type_name
	0, // [0:0] is the sub-list for extension extendee
	0, // [0:0] is the sub-list for field type_name
}

func init() { file_mnt_proto_init() }
func file_mnt_proto_init() {
	if File_mnt_proto != nil {
		return
	}
	file_opts_proto_init()
	if !protoimpl.UnsafeEnabled {
		file_mnt_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*MntEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_mnt_proto_rawDesc,
			NumEnums:      1,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_mnt_proto_goTypes,
		DependencyIndexes: file_mnt_proto_depIdxs,
		EnumInfos:         file_mnt_proto_enumTypes,
		MessageInfos:      file_mnt_proto_msgTypes,
	}.Build()
	File_mnt_proto = out.File
	file_mnt_proto_rawDesc = nil
	file_mnt_proto_goTypes = nil
	file_mnt_proto_depIdxs = nil
}
