// SPDX-License-Identifier: MIT

syntax = "proto2";

import "opts.proto";

message user_aarch64_regs_entry {
	repeated uint64 regs	= 1;
	required uint64 sp	= 2;
	required uint64 pc	= 3;
	required uint64 pstate	= 4;
}

message user_aarch64_fpsimd_context_entry {
	repeated uint64 vregs	= 1;
	required uint32 fpsr	= 2;
	required uint32 fpcr	= 3;
}

message thread_info_aarch64 {
	required uint64			 		clear_tid_addr	= 1[(criu).hex = true];
	required uint64					tls		= 2;
	required user_aarch64_regs_entry		gpregs		= 3[(criu).hex = true];
	required user_aarch64_fpsimd_context_entry	fpsimd		= 4;
}
